@charset "UTF-8";
html {
  box-sizing: border-box;
  -webkit-text-size-adjust: none;
     -moz-text-size-adjust: none;
          text-size-adjust: none;
}

*,*::before,*::after {
  box-sizing: inherit;
}
@media (prefers-reduced-motion) {
  *,*::before,*::after {
    transition: none !important;
  }
}

body {
  margin: 0;
}

a,button,label,input {
  -webkit-tap-highlight-color: transparent;
}

a {
  color: inherit;
  text-decoration: none;
}

hr {
  display: block;
  box-sizing: content-box;
  height: 0.05rem;
  padding: 0;
  overflow: visible;
  border: 0;
}

small {
  font-size: 80%;
}

sub,sup {
  line-height: 1em;
}

img {
  border-style: none;
}

table {
  border-collapse: separate;
  border-spacing: 0;
}

td,th {
  font-weight: 400;
  vertical-align: top;
}

button {
  margin: 0;
  padding: 0;
  font-size: inherit;
  font-family: inherit;
  background: transparent;
  border: 0;
}

input {
  border: 0;
  outline: none;
}

:root {
  --md-primary-fg-color: hsla(231, 48%, 48%, 1);
  --md-primary-fg-color--light: hsla(231, 44%, 56%, 1);
  --md-primary-fg-color--dark: hsla(232, 54%, 41%, 1);
  --md-primary-bg-color: hsla(0, 0%, 100%, 1);
  --md-primary-bg-color--light: hsla(0, 0%, 100%, 0.7);
  --md-accent-fg-color: hsla(231, 99%, 66%, 1);
  --md-accent-fg-color--transparent: hsla(231, 99%, 66%, 0.1);
  --md-accent-bg-color: hsla(0, 0%, 100%, 1);
  --md-accent-bg-color--light: hsla(0, 0%, 100%, 0.7);
}

:root,[data-md-color-scheme=default] {
  --md-default-fg-color: hsla(0, 0%, 0%, 0.87);
  --md-default-fg-color--light: hsla(0, 0%, 0%, 0.54);
  --md-default-fg-color--lighter: hsla(0, 0%, 0%, 0.32);
  --md-default-fg-color--lightest: hsla(0, 0%, 0%, 0.07);
  --md-default-bg-color: hsla(0, 0%, 100%, 1);
  --md-default-bg-color--light: hsla(0, 0%, 100%, 0.7);
  --md-default-bg-color--lighter: hsla(0, 0%, 100%, 0.3);
  --md-default-bg-color--lightest: hsla(0, 0%, 100%, 0.12);
  --md-code-fg-color: hsla(200, 18%, 26%, 1);
  --md-code-bg-color: hsla(0, 0%, 96%, 1);
  --md-code-hl-color: hsla(60, 100%, 50%, 0.5);
  --md-code-hl-number-color: hsla(0, 67%, 50%, 1);
  --md-code-hl-special-color: hsla(340, 83%, 47%, 1);
  --md-code-hl-function-color: hsla(291, 45%, 50%, 1);
  --md-code-hl-constant-color: hsla(250, 63%, 60%, 1);
  --md-code-hl-keyword-color: hsla(219, 54%, 51%, 1);
  --md-code-hl-string-color: hsla(150, 63%, 30%, 1);
  --md-code-hl-name-color: var(--md-code-fg-color);
  --md-code-hl-operator-color: var(--md-default-fg-color--light);
  --md-code-hl-punctuation-color: var(--md-default-fg-color--light);
  --md-code-hl-comment-color: var(--md-default-fg-color--light);
  --md-code-hl-generic-color: var(--md-default-fg-color--light);
  --md-code-hl-variable-color: var(--md-default-fg-color--light);
  --md-typeset-color: var(--md-default-fg-color);
  --md-typeset-a-color: var(--md-primary-fg-color);
  --md-typeset-mark-color: hsla(60, 100%, 50%, 0.5);
  --md-typeset-del-color: hsla(6, 90%, 60%, 0.15);
  --md-typeset-ins-color: hsla(150, 90%, 44%, 0.15);
  --md-typeset-kbd-color: hsla(0, 0%, 98%, 1);
  --md-typeset-kbd-accent-color: hsla(0, 100%, 100%, 1);
  --md-typeset-kbd-border-color: hsla(0, 0%, 72%, 1);
  --md-typeset-table-color: hsla(0, 0%, 0%, 0.12);
  --md-admonition-fg-color: var(--md-default-fg-color);
  --md-admonition-bg-color: var(--md-default-bg-color);
  --md-footer-fg-color: hsla(0, 0%, 100%, 1);
  --md-footer-fg-color--light: hsla(0, 0%, 100%, 0.7);
  --md-footer-fg-color--lighter: hsla(0, 0%, 100%, 0.45);
  --md-footer-bg-color: hsla(0, 0%, 0%, 0.87);
  --md-footer-bg-color--dark: hsla(0, 0%, 0%, 0.32);
  --md-shadow-z1:
    0 0.2rem 0.5rem hsla(0, 0%, 0%, 0.05),
    0 0 0.05rem hsla(0, 0%, 0%, 0.1);
  --md-shadow-z2:
    0 0.2rem 0.5rem hsla(0, 0%, 0%, 0.1),
    0 0 0.05rem hsla(0, 0%, 0%, 0.25);
  --md-shadow-z3:
    0 0.2rem 0.5rem hsla(0, 0%, 0%, 0.2),
    0 0 0.05rem hsla(0, 0%, 0%, 0.35);
}

.md-icon svg {
  display: block;
  width: 1.2rem;
  height: 1.2rem;
  fill: currentcolor;
}

body {
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  --md-text-font-family:
    var(--md-text-font, _),
    -apple-system, BlinkMacSystemFont, Helvetica, Arial, sans-serif;
  --md-code-font-family:
    var(--md-code-font, _),
    SFMono-Regular, Consolas, Menlo, monospace;
}

body,input,aside {
  color: var(--md-typeset-color);
  font-feature-settings: "kern", "liga";
  font-family: var(--md-text-font-family);
}

code,pre,kbd {
  font-feature-settings: "kern";
  font-family: var(--md-code-font-family);
}

:root {
  --md-typeset-table-sort-icon: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='m18 21-4-4h3V7h-3l4-4 4 4h-3v10h3M2 19v-2h10v2M2 13v-2h7v2M2 7V5h4v2H2Z'/></svg>");
  --md-typeset-table-sort-icon--asc: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M19 17h3l-4 4-4-4h3V3h2M2 17h10v2H2M6 5v2H2V5m0 6h7v2H2v-2Z'/></svg>");
  --md-typeset-table-sort-icon--desc: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M19 7h3l-4-4-4 4h3v14h2M2 17h10v2H2M6 5v2H2V5m0 6h7v2H2v-2Z'/></svg>");
}

.md-typeset {
  font-size: 0.8rem;
  line-height: 1.6;
  -webkit-print-color-adjust: exact;
          color-adjust: exact;
}
@media print {
  .md-typeset {
    font-size: 0.68rem;
  }
}
.md-typeset ul,.md-typeset ol,.md-typeset dl,.md-typeset figure,.md-typeset blockquote,.md-typeset pre {
  margin-top: 1em;
  margin-bottom: 1em;
}
.md-typeset h1 {
  margin: 0 0 1.25em;
  color: var(--md-default-fg-color--light);
  font-weight: 300;
  font-size: 2em;
  line-height: 1.3;
  letter-spacing: -0.01em;
}
.md-typeset h2 {
  margin: 1.6em 0 0.64em;
  font-weight: 300;
  font-size: 1.5625em;
  line-height: 1.4;
  letter-spacing: -0.01em;
}
.md-typeset h3 {
  margin: 1.6em 0 0.8em;
  font-weight: 400;
  font-size: 1.25em;
  line-height: 1.5;
  letter-spacing: -0.01em;
}
.md-typeset h2+h3 {
  margin-top: 0.8em;
}
.md-typeset h4 {
  margin: 1em 0;
  font-weight: 700;
  letter-spacing: -0.01em;
}
.md-typeset h5,.md-typeset h6 {
  margin: 1.25em 0;
  color: var(--md-default-fg-color--light);
  font-weight: 700;
  font-size: 0.8em;
  letter-spacing: -0.01em;
}
.md-typeset h5 {
  text-transform: uppercase;
}
.md-typeset hr {
  display: flow-root;
  margin: 1.5em 0;
  border-bottom: 0.05rem solid var(--md-default-fg-color--lightest);
}
.md-typeset a {
  color: var(--md-typeset-a-color);
  word-break: break-word;
}
.md-typeset a,.md-typeset a::before {
  transition: color 125ms;
}
.md-typeset a:focus,.md-typeset a:hover {
  color: var(--md-accent-fg-color);
}
.md-typeset a:focus code,.md-typeset a:hover code {
  background-color: var(--md-accent-fg-color--transparent);
}
.md-typeset a code {
  color: currentcolor;
  transition: background-color 125ms;
}
.md-typeset a.focus-visible {
  outline-color: var(--md-accent-fg-color);
  outline-offset: 0.2rem;
}
.md-typeset code,.md-typeset pre,.md-typeset kbd {
  color: var(--md-code-fg-color);
  direction: ltr;
  font-variant-ligatures: none;
}
@media print {
  .md-typeset code,.md-typeset pre,.md-typeset kbd {
    white-space: pre-wrap;
  }
}
.md-typeset code {
  padding: 0 0.2941176471em;
  font-size: 0.85em;
  word-break: break-word;
  background-color: var(--md-code-bg-color);
  border-radius: 0.1rem;
  -webkit-box-decoration-break: clone;
          box-decoration-break: clone;
}
.md-typeset code:not(.focus-visible) {
  outline: none;
  -webkit-tap-highlight-color: transparent;
}
.md-typeset pre {
  position: relative;
  display: flow-root;
  line-height: 1.4;
}
.md-typeset pre>code {
  display: block;
  margin: 0;
  padding: 0.7720588235em 1.1764705882em;
  overflow: auto;
  word-break: normal;
  outline-color: var(--md-accent-fg-color);
  box-shadow: none;
  -webkit-box-decoration-break: slice;
          box-decoration-break: slice;
  touch-action: auto;
  scrollbar-width: thin;
  scrollbar-color: var(--md-default-fg-color--lighter) transparent;
}
.md-typeset pre>code:hover {
  scrollbar-color: var(--md-accent-fg-color) transparent;
}
.md-typeset pre>code::-webkit-scrollbar {
  width: 0.2rem;
  height: 0.2rem;
}
.md-typeset pre>code::-webkit-scrollbar-thumb {
  background-color: var(--md-default-fg-color--lighter);
}
.md-typeset pre>code::-webkit-scrollbar-thumb:hover {
  background-color: var(--md-accent-fg-color);
}
.md-typeset kbd {
  display: inline-block;
  padding: 0 0.6666666667em;
  color: var(--md-default-fg-color);
  font-size: 0.75em;
  vertical-align: text-top;
  word-break: break-word;
  background-color: var(--md-typeset-kbd-color);
  border-radius: 0.1rem;
  box-shadow: 0 0.1rem 0 0.05rem var(--md-typeset-kbd-border-color), 0 0.1rem 0 var(--md-typeset-kbd-border-color), 0 -0.1rem 0.2rem var(--md-typeset-kbd-accent-color) inset;
}
.md-typeset mark {
  color: inherit;
  word-break: break-word;
  background-color: var(--md-typeset-mark-color);
  -webkit-box-decoration-break: clone;
          box-decoration-break: clone;
}
.md-typeset abbr {
  text-decoration: none;
  border-bottom: 0.05rem dotted var(--md-default-fg-color--light);
  cursor: help;
}
@media (hover: none) {
  .md-typeset abbr[title]:focus::after,.md-typeset abbr[title]:hover::after {
    position: absolute;
    left: 0.8rem;
    right: 0.8rem;
    margin-top: 2em;
    padding: 0.2rem 0.3rem;
    color: var(--md-default-bg-color);
    font-size: 0.7rem;
    background-color: var(--md-default-fg-color);
    border-radius: 0.1rem;
    box-shadow: var(--md-shadow-z3);
    content: attr(title);
  }
}
.md-typeset small {
  opacity: 0.75;
}
[dir="ltr"] .md-typeset sup,[dir="ltr"] .md-typeset sub{
  margin-left: 0.078125em;
}
[dir="rtl"] .md-typeset sup,[dir="rtl"] .md-typeset sub{
  margin-right: 0.078125em;
}
[dir="ltr"] .md-typeset blockquote{
  padding-left: 0.6rem;
}
[dir="rtl"] .md-typeset blockquote{
  padding-right: 0.6rem;
}
[dir="ltr"] .md-typeset blockquote{
  border-left: 0.2rem solid var(--md-default-fg-color--lighter);
}
[dir="rtl"] .md-typeset blockquote{
  border-right: 0.2rem solid var(--md-default-fg-color--lighter);
}
.md-typeset blockquote {
  margin-left: 0;
  margin-right: 0;
  color: var(--md-default-fg-color--light);
}
.md-typeset ul {
  list-style-type: disc;
}
[dir="ltr"] .md-typeset ul,[dir="ltr"] .md-typeset ol{
  margin-left: 0.625em;
}
[dir="rtl"] .md-typeset ul,[dir="rtl"] .md-typeset ol{
  margin-right: 0.625em;
}
.md-typeset ul,.md-typeset ol {
  padding: 0;
}
.md-typeset ul:not([hidden]),.md-typeset ol:not([hidden]) {
  display: flow-root;
}
.md-typeset ul ol,.md-typeset ol ol {
  list-style-type: lower-alpha;
}
.md-typeset ul ol ol,.md-typeset ol ol ol {
  list-style-type: lower-roman;
}
[dir="ltr"] .md-typeset ul li,[dir="ltr"] .md-typeset ol li{
  margin-left: 1.25em;
}
[dir="rtl"] .md-typeset ul li,[dir="rtl"] .md-typeset ol li{
  margin-right: 1.25em;
}
.md-typeset ul li,.md-typeset ol li {
  margin-bottom: 0.5em;
}
.md-typeset ul li p,.md-typeset ul li blockquote,.md-typeset ol li p,.md-typeset ol li blockquote {
  margin: 0.5em 0;
}
.md-typeset ul li:last-child,.md-typeset ol li:last-child {
  margin-bottom: 0;
}
[dir="ltr"] .md-typeset ul li ul,[dir="ltr"] .md-typeset ul li ol,[dir="ltr"] .md-typeset ol li ul,[dir="ltr"] .md-typeset ol li ol{
  margin-left: 0.625em;
}
[dir="rtl"] .md-typeset ul li ul,[dir="rtl"] .md-typeset ul li ol,[dir="rtl"] .md-typeset ol li ul,[dir="rtl"] .md-typeset ol li ol{
  margin-right: 0.625em;
}
.md-typeset ul li ul,.md-typeset ul li ol,.md-typeset ol li ul,.md-typeset ol li ol {
  margin-top: 0.5em;
  margin-bottom: 0.5em;
}
[dir="ltr"] .md-typeset dd{
  margin-left: 1.875em;
}
[dir="rtl"] .md-typeset dd{
  margin-right: 1.875em;
}
.md-typeset dd {
  margin-top: 1em;
  margin-bottom: 1.5em;
}
.md-typeset img,.md-typeset svg,.md-typeset video {
  max-width: 100%;
  height: auto;
}
.md-typeset img[align=left] {
  margin: 1em;
  margin-left: 0;
}
.md-typeset img[align=right] {
  margin: 1em;
  margin-right: 0;
}
.md-typeset img[align]:only-child {
  margin-top: 0;
}
.md-typeset img[src$="#only-dark"],.md-typeset img[src$="#gh-dark-mode-only"] {
  display: none;
}
.md-typeset figure {
  display: flow-root;
  width: -webkit-fit-content;
  width: -moz-fit-content;
  width: fit-content;
  max-width: 100%;
  margin: 1em auto;
  text-align: center;
}
.md-typeset figure img {
  display: block;
}
.md-typeset figcaption {
  max-width: 24rem;
  margin: 1em auto;
  font-style: italic;
}
.md-typeset iframe {
  max-width: 100%;
}
.md-typeset table:not([class]) {
  display: inline-block;
  max-width: 100%;
  overflow: auto;
  font-size: 0.64rem;
  background-color: var(--md-default-bg-color);
  border: 0.05rem solid var(--md-typeset-table-color);
  border-radius: 0.1rem;
  touch-action: auto;
}
@media print {
  .md-typeset table:not([class]) {
    display: table;
  }
}
.md-typeset table:not([class])+* {
  margin-top: 1.5em;
}
.md-typeset table:not([class]) th>*:first-child,.md-typeset table:not([class]) td>*:first-child {
  margin-top: 0;
}
.md-typeset table:not([class]) th>*:last-child,.md-typeset table:not([class]) td>*:last-child {
  margin-bottom: 0;
}
.md-typeset table:not([class]) th:not([align]),.md-typeset table:not([class]) td:not([align]) {
  text-align: left;
}
[dir=rtl] .md-typeset table:not([class]) th:not([align]),[dir=rtl] .md-typeset table:not([class]) td:not([align]) {
  text-align: right;
}
.md-typeset table:not([class]) th {
  min-width: 5rem;
  padding: 0.9375em 1.25em;
  font-weight: 700;
  vertical-align: top;
}
.md-typeset table:not([class]) td {
  padding: 0.9375em 1.25em;
  vertical-align: top;
  border-top: 0.05rem solid var(--md-typeset-table-color);
}
.md-typeset table:not([class]) tbody tr {
  transition: background-color 125ms;
}
.md-typeset table:not([class]) tbody tr:hover {
  background-color: rgba(0, 0, 0, 0.035);
  box-shadow: 0 0.05rem 0 var(--md-default-bg-color) inset;
}
.md-typeset table:not([class]) a {
  word-break: normal;
}
.md-typeset table th[role=columnheader] {
  cursor: pointer;
}
[dir="ltr"] .md-typeset table th[role=columnheader]::after{
  margin-left: 0.5em;
}
[dir="rtl"] .md-typeset table th[role=columnheader]::after{
  margin-right: 0.5em;
}
.md-typeset table th[role=columnheader]::after {
  display: inline-block;
  width: 1.2em;
  height: 1.2em;
  vertical-align: text-bottom;
  -webkit-mask-image: var(--md-typeset-table-sort-icon);
          mask-image: var(--md-typeset-table-sort-icon);
  -webkit-mask-repeat: no-repeat;
          mask-repeat: no-repeat;
  -webkit-mask-size: contain;
          mask-size: contain;
  transition: background-color 125ms;
  content: "";
}
.md-typeset table th[role=columnheader]:hover::after {
  background-color: var(--md-default-fg-color--lighter);
}
.md-typeset table th[role=columnheader][aria-sort=ascending]::after {
  background-color: var(--md-default-fg-color--light);
  -webkit-mask-image: var(--md-typeset-table-sort-icon--asc);
          mask-image: var(--md-typeset-table-sort-icon--asc);
}
.md-typeset table th[role=columnheader][aria-sort=descending]::after {
  background-color: var(--md-default-fg-color--light);
  -webkit-mask-image: var(--md-typeset-table-sort-icon--desc);
          mask-image: var(--md-typeset-table-sort-icon--desc);
}
.md-typeset__scrollwrap {
  margin: 1em -0.8rem;
  overflow-x: auto;
  touch-action: auto;
}
.md-typeset__table {
  display: inline-block;
  margin-bottom: 0.5em;
  padding: 0 0.8rem;
}
@media print {
  .md-typeset__table {
    display: block;
  }
}
html .md-typeset__table table {
  display: table;
  width: 100%;
  margin: 0;
  overflow: hidden;
}

@media screen and (max-width: 44.9375em) {
  .md-content__inner>pre {
    margin: 1em -0.8rem;
  }
  .md-content__inner>pre code {
    border-radius: 0;
  }
}
.md-banner {
  overflow: auto;
  color: var(--md-footer-fg-color);
  background-color: var(--md-footer-bg-color);
}
@media print {
  .md-banner {
    display: none;
  }
}
.md-banner--warning {
  color: var(--md-default-fg-color);
  background: var(--md-typeset-mark-color);
}
.md-banner__inner {
  margin: 0.6rem auto;
  padding: 0 0.8rem;
  font-size: 0.7rem;
}
[dir="ltr"] .md-banner__button{
  float: right;
}
[dir="rtl"] .md-banner__button{
  float: left;
}
.md-banner__button {
  color: inherit;
  cursor: pointer;
  transition: opacity 250ms;
}
.md-banner__button:hover {
  opacity: 0.7;
}

html {
  height: 100%;
  overflow-x: hidden;
  font-size: 125%;
}
@media screen and (min-width: 100em) {
  html {
    font-size: 137.5%;
  }
}
@media screen and (min-width: 125em) {
  html {
    font-size: 150%;
  }
}

body {
  position: relative;
  display: flex;
  flex-direction: column;
  width: 100%;
  min-height: 100%;
  font-size: 0.5rem;
  background-color: var(--md-default-bg-color);
}
@media print {
  body {
    display: block;
  }
}
@media screen and (max-width: 59.9375em) {
  body[data-md-scrolllock] {
    position: fixed;
  }
}

.md-grid {
  max-width: 72rem;
  margin-left: auto;
  margin-right: auto;
}

.md-container {
  display: flex;
  flex-direction: column;
  flex-grow: 1;
}
@media print {
  .md-container {
    display: block;
  }
}

.md-main {
  flex-grow: 1;
}
.md-main__inner {
  display: flex;
  height: 100%;
  margin-top: 1.5rem;
}

.md-ellipsis {
  overflow: hidden;
  white-space: nowrap;
  text-overflow: ellipsis;
}

.md-toggle {
  display: none;
}

.md-option {
  position: absolute;
  width: 0;
  height: 0;
  opacity: 0;
}
.md-option:checked+label:not([hidden]) {
  display: block;
}
.md-option.focus-visible+label {
  outline-style: auto;
  outline-color: var(--md-accent-fg-color);
}

.md-skip {
  position: fixed;
  z-index: -1;
  margin: 0.5rem;
  padding: 0.3rem 0.5rem;
  color: var(--md-default-bg-color);
  font-size: 0.64rem;
  background-color: var(--md-default-fg-color);
  border-radius: 0.1rem;
  outline-color: var(--md-accent-fg-color);
  transform: translateY(0.4rem);
  opacity: 0;
}
.md-skip:focus {
  z-index: 10;
  transform: translateY(0);
  opacity: 1;
  transition: transform 250ms cubic-bezier(0.4, 0, 0.2, 1), opacity 175ms 75ms;
}

@page {
  margin: 25mm;
}
:root {
  --md-clipboard-icon: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M19 21H8V7h11m0-2H8a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h11a2 2 0 0 0 2-2V7a2 2 0 0 0-2-2m-3-4H4a2 2 0 0 0-2 2v14h2V3h12V1Z'/></svg>");
}

.md-clipboard {
  position: absolute;
  top: 0.5em;
  right: 0.5em;
  z-index: 1;
  width: 1.5em;
  height: 1.5em;
  color: var(--md-default-fg-color--lightest);
  border-radius: 0.1rem;
  outline-color: var(--md-accent-fg-color);
  outline-offset: 0.1rem;
  cursor: pointer;
  transition: color 250ms;
}
@media print {
  .md-clipboard {
    display: none;
  }
}
.md-clipboard:not(.focus-visible) {
  outline: none;
  -webkit-tap-highlight-color: transparent;
}
:hover>.md-clipboard {
  color: var(--md-default-fg-color--light);
}
.md-clipboard:focus,.md-clipboard:hover {
  color: var(--md-accent-fg-color);
}
.md-clipboard::after {
  display: block;
  width: 1.125em;
  height: 1.125em;
  margin: 0 auto;
  background-color: currentcolor;
  -webkit-mask-image: var(--md-clipboard-icon);
          mask-image: var(--md-clipboard-icon);
  -webkit-mask-position: center;
          mask-position: center;
  -webkit-mask-repeat: no-repeat;
          mask-repeat: no-repeat;
  -webkit-mask-size: contain;
          mask-size: contain;
  content: "";
}
.md-clipboard--inline {
  cursor: pointer;
}
.md-clipboard--inline code {
  transition: color 250ms, background-color 250ms;
}
.md-clipboard--inline:focus code,.md-clipboard--inline:hover code {
  color: var(--md-accent-fg-color);
  background-color: var(--md-accent-fg-color--transparent);
}

@keyframes consent {
  0% {
    transform: translateY(100%);
    opacity: 0;
  }
  100% {
    transform: translateY(0);
    opacity: 1;
  }
}
@keyframes overlay {
  0% {
    opacity: 0;
  }
  100% {
    opacity: 1;
  }
}
.md-consent__overlay {
  position: fixed;
  top: 0;
  z-index: 5;
  width: 100%;
  height: 100%;
  background-color: hsla(0deg, 0%, 0%, 0.54);
  opacity: 1;
  -webkit-backdrop-filter: blur(0.1rem);
          backdrop-filter: blur(0.1rem);
  animation: overlay 250ms both;
}
.md-consent__inner {
  position: fixed;
  bottom: 0;
  z-index: 5;
  width: 100%;
  max-height: 100%;
  padding: 0;
  overflow: auto;
  background-color: var(--md-default-bg-color);
  border: 0;
  border-radius: 0.1rem;
  box-shadow: 0 0 0.2rem rgba(0, 0, 0, 0.1), 0 0.2rem 0.4rem rgba(0, 0, 0, 0.2);
  animation: consent 500ms cubic-bezier(0.1, 0.7, 0.1, 1) both;
}
.md-consent__form {
  padding: 0.8rem;
}
.md-consent__settings {
  display: none;
  margin: 1em 0;
}
input:checked+.md-consent__settings {
  display: block;
}
.md-consent__controls {
  margin-bottom: 0.8rem;
}
.md-typeset .md-consent__controls .md-button {
  display: inline;
}
@media screen and (max-width: 44.9375em) {
  .md-typeset .md-consent__controls .md-button {
    display: block;
    width: 100%;
    margin-top: 0.4rem;
    text-align: center;
  }
}
.md-consent label {
  cursor: pointer;
}

.md-content {
  flex-grow: 1;
  min-width: 0;
}
.md-content__inner {
  margin: 0 0.8rem 1.2rem;
  padding-top: 0.6rem;
}
@media screen and (min-width: 76.25em) {
  [dir="ltr"] .md-sidebar--primary:not([hidden])~.md-content>.md-content__inner{
    margin-left: 1.2rem;
  }
  [dir="rtl"] .md-sidebar--primary:not([hidden])~.md-content>.md-content__inner{
    margin-right: 1.2rem;
  }
  [dir="ltr"] .md-sidebar--secondary:not([hidden])~.md-content>.md-content__inner{
    margin-right: 1.2rem;
  }
  [dir="rtl"] .md-sidebar--secondary:not([hidden])~.md-content>.md-content__inner{
    margin-left: 1.2rem;
  }
}
.md-content__inner::before {
  display: block;
  height: 0.4rem;
  content: "";
}
.md-content__inner>:last-child {
  margin-bottom: 0;
}
[dir="ltr"] .md-content__button{
  float: right;
}
[dir="rtl"] .md-content__button{
  float: left;
}
[dir="ltr"] .md-content__button{
  margin-left: 0.4rem;
}
[dir="rtl"] .md-content__button{
  margin-right: 0.4rem;
}
.md-content__button {
  margin: 0.4rem 0;
  padding: 0;
}
@media print {
  .md-content__button {
    display: none;
  }
}
.md-typeset .md-content__button {
  color: var(--md-default-fg-color--lighter);
}
.md-content__button svg {
  display: inline;
  vertical-align: top;
}
[dir=rtl] .md-content__button svg {
  transform: scaleX(-1);
}

[dir="ltr"] .md-dialog{
  right: 0.8rem;
}

[dir="rtl"] .md-dialog{
  left: 0.8rem;
}

.md-dialog {
  position: fixed;
  bottom: 0.8rem;
  z-index: 4;
  min-width: 11.1rem;
  padding: 0.4rem 0.6rem;
  background-color: var(--md-default-fg-color);
  border-radius: 0.1rem;
  box-shadow: var(--md-shadow-z3);
  transform: translateY(100%);
  opacity: 0;
  transition: transform 0ms 400ms, opacity 400ms;
  pointer-events: none;
}
@media print {
  .md-dialog {
    display: none;
  }
}
.md-dialog--active {
  transform: translateY(0);
  opacity: 1;
  transition: transform 400ms cubic-bezier(0.075, 0.85, 0.175, 1), opacity 400ms;
  pointer-events: initial;
}
.md-dialog__inner {
  color: var(--md-default-bg-color);
  font-size: 0.7rem;
}

.md-feedback {
  margin: 2em 0 1em;
  text-align: center;
}
.md-feedback fieldset {
  margin: 0;
  padding: 0;
  border: none;
}
.md-feedback__title {
  margin: 1em auto;
  font-weight: 700;
}
.md-feedback__inner {
  position: relative;
}
.md-feedback__list {
  position: relative;
  display: flex;
  flex-wrap: wrap;
  align-content: baseline;
  justify-content: center;
}
.md-feedback__list:hover .md-icon:not(:disabled) {
  color: var(--md-default-fg-color--lighter);
}
:disabled .md-feedback__list {
  min-height: 1.8rem;
}
.md-feedback__icon {
  flex-shrink: 0;
  margin: 0 0.1rem;
  color: var(--md-default-fg-color--light);
  cursor: pointer;
  transition: color 125ms;
}
.md-feedback__icon:not(:disabled).md-icon:hover {
  color: var(--md-accent-fg-color);
}
.md-feedback__icon:disabled {
  color: var(--md-default-fg-color--lightest);
  pointer-events: none;
}
.md-feedback__note {
  position: relative;
  transform: translateY(0.4rem);
  opacity: 0;
  transition: transform 400ms cubic-bezier(0.1, 0.7, 0.1, 1), opacity 150ms;
}
.md-feedback__note>* {
  max-width: 16rem;
  margin: 0 auto;
}
:disabled .md-feedback__note {
  transform: translateY(0);
  opacity: 1;
}

.md-footer {
  color: var(--md-footer-fg-color);
  background-color: var(--md-footer-bg-color);
}
@media print {
  .md-footer {
    display: none;
  }
}
.md-footer__inner {
  justify-content: space-between;
  padding: 0.2rem;
  overflow: auto;
}
.md-footer__inner:not([hidden]) {
  display: flex;
}
.md-footer__link {
  display: flex;
  flex-grow: 0.01;
  padding-top: 1.4rem;
  padding-bottom: 0.4rem;
  overflow: hidden;
  outline-color: var(--md-accent-fg-color);
  transition: opacity 250ms;
}
.md-footer__link:focus,.md-footer__link:hover {
  opacity: 0.7;
}
[dir=rtl] .md-footer__link svg {
  transform: scaleX(-1);
}
@media screen and (max-width: 44.9375em) {
  .md-footer__link--prev .md-footer__title {
    display: none;
  }
}
[dir="ltr"] .md-footer__link--next{
  margin-left: auto;
}
[dir="rtl"] .md-footer__link--next{
  margin-right: auto;
}
.md-footer__link--next {
  text-align: right;
}
[dir=rtl] .md-footer__link--next {
  text-align: left;
}
.md-footer__title {
  position: relative;
  flex-grow: 1;
  max-width: calc(100% - 2.4rem);
  padding: 0 1rem;
  font-size: 0.9rem;
  line-height: 2.4rem;
  white-space: nowrap;
}
.md-footer__button {
  margin: 0.2rem;
  padding: 0.4rem;
}
.md-footer__direction {
  position: absolute;
  left: 0;
  right: 0;
  margin-top: -1rem;
  padding: 0 1rem;
  font-size: 0.64rem;
  opacity: 0.7;
}

.md-footer-meta {
  background-color: var(--md-footer-bg-color--dark);
}
.md-footer-meta__inner {
  display: flex;
  flex-wrap: wrap;
  justify-content: space-between;
  padding: 0.2rem;
}
html .md-footer-meta.md-typeset a {
  color: var(--md-footer-fg-color--light);
}
html .md-footer-meta.md-typeset a:focus,html .md-footer-meta.md-typeset a:hover {
  color: var(--md-footer-fg-color);
}

.md-copyright {
  width: 100%;
  margin: auto 0.6rem;
  padding: 0.4rem 0;
  color: var(--md-footer-fg-color--lighter);
  font-size: 0.64rem;
}
@media screen and (min-width: 45em) {
  .md-copyright {
    width: auto;
  }
}
.md-copyright__highlight {
  color: var(--md-footer-fg-color--light);
}

.md-social {
  margin: 0 0.4rem;
  padding: 0.2rem 0 0.6rem;
}
@media screen and (min-width: 45em) {
  .md-social {
    padding: 0.6rem 0;
  }
}
.md-social__link {
  display: inline-block;
  width: 1.6rem;
  height: 1.6rem;
  text-align: center;
}
.md-social__link::before {
  line-height: 1.9;
}
.md-social__link svg {
  max-height: 0.8rem;
  vertical-align: -25%;
  fill: currentcolor;
}

.md-typeset .md-button {
  display: inline-block;
  padding: 0.625em 2em;
  color: var(--md-primary-fg-color);
  font-weight: 700;
  border: 0.1rem solid currentcolor;
  border-radius: 0.1rem;
  cursor: pointer;
  transition: color 125ms, background-color 125ms, border-color 125ms;
}
.md-typeset .md-button--primary {
  color: var(--md-primary-bg-color);
  background-color: var(--md-primary-fg-color);
  border-color: var(--md-primary-fg-color);
}
.md-typeset .md-button:focus,.md-typeset .md-button:hover {
  color: var(--md-accent-bg-color);
  background-color: var(--md-accent-fg-color);
  border-color: var(--md-accent-fg-color);
}
[dir="ltr"] .md-typeset .md-input{
  border-top-left-radius: 0.1rem;
}
[dir="rtl"] .md-typeset .md-input{
  border-top-right-radius: 0.1rem;
}
[dir="ltr"] .md-typeset .md-input{
  border-top-right-radius: 0.1rem;
}
[dir="rtl"] .md-typeset .md-input{
  border-top-left-radius: 0.1rem;
}
.md-typeset .md-input {
  height: 1.8rem;
  padding: 0 0.6rem;
  font-size: 0.8rem;
  border-bottom: 0.1rem solid var(--md-default-fg-color--lighter);
  box-shadow: var(--md-shadow-z1);
  transition: border 250ms, box-shadow 250ms;
}
.md-typeset .md-input:focus,.md-typeset .md-input:hover {
  border-bottom-color: var(--md-accent-fg-color);
  box-shadow: var(--md-shadow-z2);
}
.md-typeset .md-input--stretch {
  width: 100%;
}

.md-header {
  position: -webkit-sticky;
  position: sticky;
  top: 0;
  left: 0;
  right: 0;
  z-index: 4;
  display: block;
  color: var(--md-primary-bg-color);
  background-color: var(--md-primary-fg-color);
  box-shadow: 0 0 0.2rem rgba(0, 0, 0, 0), 0 0.2rem 0.4rem rgba(0, 0, 0, 0);
}
@media print {
  .md-header {
    display: none;
  }
}
.md-header[hidden] {
  transform: translateY(-100%);
  transition: transform 250ms cubic-bezier(0.8, 0, 0.6, 1), box-shadow 250ms;
}
.md-header--shadow {
  box-shadow: 0 0 0.2rem rgba(0, 0, 0, 0.1), 0 0.2rem 0.4rem rgba(0, 0, 0, 0.2);
  transition: transform 250ms cubic-bezier(0.1, 0.7, 0.1, 1), box-shadow 250ms;
}
.md-header__inner {
  display: flex;
  align-items: center;
  padding: 0 0.2rem;
}
.md-header__button {
  position: relative;
  z-index: 1;
  margin: 0.2rem;
  padding: 0.4rem;
  color: currentcolor;
  vertical-align: middle;
  outline-color: var(--md-accent-fg-color);
  cursor: pointer;
  transition: opacity 250ms;
}
.md-header__button:hover {
  opacity: 0.7;
}
.md-header__button:not([hidden]) {
  display: inline-block;
}
.md-header__button:not(.focus-visible) {
  outline: none;
  -webkit-tap-highlight-color: transparent;
}
.md-header__button.md-logo {
  margin: 0.2rem;
  padding: 0.4rem;
}
@media screen and (max-width: 76.1875em) {
  .md-header__button.md-logo {
    display: none;
  }
}
.md-header__button.md-logo img,.md-header__button.md-logo svg {
  display: block;
  width: auto;
  height: 1.2rem;
  fill: currentcolor;
}
@media screen and (min-width: 60em) {
  .md-header__button[for=__search] {
    display: none;
  }
}
.no-js .md-header__button[for=__search] {
  display: none;
}
[dir=rtl] .md-header__button[for=__search] svg {
  transform: scaleX(-1);
}
@media screen and (min-width: 76.25em) {
  .md-header__button[for=__drawer] {
    display: none;
  }
}
.md-header__topic {
  position: absolute;
  display: flex;
  max-width: 100%;
  white-space: nowrap;
  transition: transform 400ms cubic-bezier(0.1, 0.7, 0.1, 1), opacity 150ms;
}
.md-header__topic+.md-header__topic {
  z-index: -1;
  transform: translateX(1.25rem);
  opacity: 0;
  transition: transform 400ms cubic-bezier(1, 0.7, 0.1, 0.1), opacity 150ms;
  pointer-events: none;
}
[dir=rtl] .md-header__topic+.md-header__topic {
  transform: translateX(-1.25rem);
}
.md-header__topic:first-child {
  font-weight: 700;
}
[dir="ltr"] .md-header__title{
  margin-right: 0.4rem;
}
[dir="rtl"] .md-header__title{
  margin-left: 0.4rem;
}
[dir="ltr"] .md-header__title{
  margin-left: 1rem;
}
[dir="rtl"] .md-header__title{
  margin-right: 1rem;
}
.md-header__title {
  flex-grow: 1;
  height: 2.4rem;
  font-size: 0.9rem;
  line-height: 2.4rem;
}
.md-header__title--active .md-header__topic {
  z-index: -1;
  transform: translateX(-1.25rem);
  opacity: 0;
  transition: transform 400ms cubic-bezier(1, 0.7, 0.1, 0.1), opacity 150ms;
  pointer-events: none;
}
[dir=rtl] .md-header__title--active .md-header__topic {
  transform: translateX(1.25rem);
}
.md-header__title--active .md-header__topic+.md-header__topic {
  z-index: 0;
  transform: translateX(0);
  opacity: 1;
  transition: transform 400ms cubic-bezier(0.1, 0.7, 0.1, 1), opacity 150ms;
  pointer-events: initial;
}
.md-header__title>.md-header__ellipsis {
  position: relative;
  width: 100%;
  height: 100%;
}
.md-header__option {
  display: flex;
  flex-shrink: 0;
  max-width: 100%;
  white-space: nowrap;
  transition: max-width 0ms 250ms, opacity 250ms 250ms;
}
[data-md-toggle=search]:checked~.md-header .md-header__option {
  max-width: 0;
  opacity: 0;
  transition: max-width 0ms, opacity 0ms;
}
.md-header__source {
  display: none;
}
@media screen and (min-width: 60em) {
  [dir="ltr"] .md-header__source{
    margin-left: 1rem;
  }
  [dir="rtl"] .md-header__source{
    margin-right: 1rem;
  }
  .md-header__source {
    display: block;
    width: 11.7rem;
    max-width: 11.7rem;
  }
}
@media screen and (min-width: 76.25em) {
  [dir="ltr"] .md-header__source{
    margin-left: 1.4rem;
  }
  [dir="rtl"] .md-header__source{
    margin-right: 1.4rem;
  }
}

:root {
  --md-nav-icon--prev: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M20 11v2H8l5.5 5.5-1.42 1.42L4.16 12l7.92-7.92L13.5 5.5 8 11h12Z'/></svg>");
  --md-nav-icon--next: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M8.59 16.58 13.17 12 8.59 7.41 10 6l6 6-6 6-1.41-1.42Z'/></svg>");
  --md-toc-icon: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M3 9h14V7H3v2m0 4h14v-2H3v2m0 4h14v-2H3v2m16 0h2v-2h-2v2m0-10v2h2V7h-2m0 6h2v-2h-2v2Z'/></svg>");
}

.md-nav {
  font-size: 0.7rem;
  line-height: 1.3;
}
.md-nav__title {
  display: block;
  padding: 0 0.6rem;
  overflow: hidden;
  color: var(--md-default-fg-color--light);
  font-weight: 700;
  text-overflow: ellipsis;
}
.md-nav__title .md-nav__button {
  display: none;
}
.md-nav__title .md-nav__button img {
  width: auto;
  height: 100%;
}
.md-nav__title .md-nav__button.md-logo img,.md-nav__title .md-nav__button.md-logo svg {
  display: block;
  width: auto;
  max-width: 100%;
  height: 2.4rem;
  object-fit: contain;
  fill: currentcolor;
}
.md-nav__list {
  margin: 0;
  padding: 0;
  list-style: none;
}
.md-nav__item {
  padding: 0 0.6rem;
}
[dir="ltr"] .md-nav__item .md-nav__item{
  padding-right: 0;
}
[dir="rtl"] .md-nav__item .md-nav__item{
  padding-left: 0;
}
.md-nav__link {
  display: flex;
  align-items: center;
  justify-content: space-between;
  margin-top: 0.625em;
  overflow: hidden;
  text-overflow: ellipsis;
  cursor: pointer;
  transition: color 125ms;
  scroll-snap-align: start;
}
.md-nav__link--passed {
  color: var(--md-default-fg-color--light);
}
.md-nav__item .md-nav__link--active {
  color: var(--md-typeset-a-color);
}
.md-nav__item .md-nav__link--index [href] {
  width: 100%;
}
.md-nav__link:focus,.md-nav__link:hover {
  color: var(--md-accent-fg-color);
}
.md-nav__link.focus-visible {
  outline-color: var(--md-accent-fg-color);
  outline-offset: 0.2rem;
}
.md-nav--primary .md-nav__link[for=__toc] {
  display: none;
}
.md-nav--primary .md-nav__link[for=__toc] .md-icon::after {
  display: block;
  width: 100%;
  height: 100%;
  -webkit-mask-image: var(--md-toc-icon);
          mask-image: var(--md-toc-icon);
  background-color: currentcolor;
}
.md-nav--primary .md-nav__link[for=__toc]~.md-nav {
  display: none;
}
.md-nav__link>* {
  display: flex;
  cursor: pointer;
}
.md-nav__icon {
  flex-shrink: 0;
}
.md-nav__source {
  display: none;
}
@media screen and (max-width: 76.1875em) {
  .md-nav--primary,.md-nav--primary .md-nav {
    position: absolute;
    top: 0;
    left: 0;
    right: 0;
    z-index: 1;
    display: flex;
    flex-direction: column;
    height: 100%;
    background-color: var(--md-default-bg-color);
  }
  .md-nav--primary .md-nav__title,.md-nav--primary .md-nav__item {
    font-size: 0.8rem;
    line-height: 1.5;
  }
  .md-nav--primary .md-nav__title {
    position: relative;
    height: 5.6rem;
    padding: 3rem 0.8rem 0.2rem;
    color: var(--md-default-fg-color--light);
    line-height: 2.4rem;
    white-space: nowrap;
    background-color: var(--md-default-fg-color--lightest);
    cursor: pointer;
  }
  [dir="ltr"] .md-nav--primary .md-nav__title .md-nav__icon{
    left: 0.4rem;
  }
  [dir="rtl"] .md-nav--primary .md-nav__title .md-nav__icon{
    right: 0.4rem;
  }
  .md-nav--primary .md-nav__title .md-nav__icon {
    position: absolute;
    top: 0.4rem;
    display: block;
    width: 1.2rem;
    height: 1.2rem;
    margin: 0.2rem;
  }
  .md-nav--primary .md-nav__title .md-nav__icon::after {
    display: block;
    width: 100%;
    height: 100%;
    background-color: currentcolor;
    -webkit-mask-image: var(--md-nav-icon--prev);
            mask-image: var(--md-nav-icon--prev);
    -webkit-mask-position: center;
            mask-position: center;
    -webkit-mask-repeat: no-repeat;
            mask-repeat: no-repeat;
    -webkit-mask-size: contain;
            mask-size: contain;
    content: "";
  }
  .md-nav--primary .md-nav__title~.md-nav__list {
    overflow-y: auto;
    background-color: var(--md-default-bg-color);
    box-shadow: 0 0.05rem 0 var(--md-default-fg-color--lightest) inset;
    scroll-snap-type: y mandatory;
    touch-action: pan-y;
  }
  .md-nav--primary .md-nav__title~.md-nav__list>:first-child {
    border-top: 0;
  }
  .md-nav--primary .md-nav__title[for=__drawer] {
    color: var(--md-primary-bg-color);
    font-weight: 700;
    background-color: var(--md-primary-fg-color);
  }
  .md-nav--primary .md-nav__title .md-logo {
    position: absolute;
    top: 0.2rem;
    left: 0.2rem;
    right: 0.2rem;
    display: block;
    margin: 0.2rem;
    padding: 0.4rem;
  }
  .md-nav--primary .md-nav__list {
    flex: 1;
  }
  .md-nav--primary .md-nav__item {
    padding: 0;
    border-top: 0.05rem solid var(--md-default-fg-color--lightest);
  }
  .md-nav--primary .md-nav__item--active>.md-nav__link {
    color: var(--md-typeset-a-color);
  }
  .md-nav--primary .md-nav__item--active>.md-nav__link:focus,.md-nav--primary .md-nav__item--active>.md-nav__link:hover {
    color: var(--md-accent-fg-color);
  }
  .md-nav--primary .md-nav__link {
    margin-top: 0;
    padding: 0.6rem 0.8rem;
  }
  [dir="ltr"] .md-nav--primary .md-nav__link .md-nav__icon{
    margin-right: -0.2rem;
  }
  [dir="rtl"] .md-nav--primary .md-nav__link .md-nav__icon{
    margin-left: -0.2rem;
  }
  .md-nav--primary .md-nav__link .md-nav__icon {
    width: 1.2rem;
    height: 1.2rem;
    font-size: 1.2rem;
  }
  .md-nav--primary .md-nav__link .md-nav__icon::after {
    display: block;
    width: 100%;
    height: 100%;
    background-color: currentcolor;
    -webkit-mask-image: var(--md-nav-icon--next);
            mask-image: var(--md-nav-icon--next);
    -webkit-mask-position: center;
            mask-position: center;
    -webkit-mask-repeat: no-repeat;
            mask-repeat: no-repeat;
    -webkit-mask-size: contain;
            mask-size: contain;
    content: "";
  }
  [dir=rtl] .md-nav--primary .md-nav__icon::after {
    transform: scale(-1);
  }
  .md-nav--primary .md-nav--secondary .md-nav {
    position: static;
    background-color: transparent;
  }
  [dir="ltr"] .md-nav--primary .md-nav--secondary .md-nav .md-nav__link{
    padding-left: 1.4rem;
  }
  [dir="rtl"] .md-nav--primary .md-nav--secondary .md-nav .md-nav__link{
    padding-right: 1.4rem;
  }
  [dir="ltr"] .md-nav--primary .md-nav--secondary .md-nav .md-nav .md-nav__link{
    padding-left: 2rem;
  }
  [dir="rtl"] .md-nav--primary .md-nav--secondary .md-nav .md-nav .md-nav__link{
    padding-right: 2rem;
  }
  [dir="ltr"] .md-nav--primary .md-nav--secondary .md-nav .md-nav .md-nav .md-nav__link{
    padding-left: 2.6rem;
  }
  [dir="rtl"] .md-nav--primary .md-nav--secondary .md-nav .md-nav .md-nav .md-nav__link{
    padding-right: 2.6rem;
  }
  [dir="ltr"] .md-nav--primary .md-nav--secondary .md-nav .md-nav .md-nav .md-nav .md-nav__link{
    padding-left: 3.2rem;
  }
  [dir="rtl"] .md-nav--primary .md-nav--secondary .md-nav .md-nav .md-nav .md-nav .md-nav__link{
    padding-right: 3.2rem;
  }
  .md-nav--secondary {
    background-color: transparent;
  }
  .md-nav__toggle~.md-nav {
    display: flex;
    transform: translateX(100%);
    opacity: 0;
    transition: transform 250ms cubic-bezier(0.8, 0, 0.6, 1), opacity 125ms 50ms;
  }
  [dir=rtl] .md-nav__toggle~.md-nav {
    transform: translateX(-100%);
  }
  .md-nav__toggle:checked~.md-nav {
    transform: translateX(0);
    opacity: 1;
    transition: transform 250ms cubic-bezier(0.4, 0, 0.2, 1), opacity 125ms 125ms;
  }
  .md-nav__toggle:checked~.md-nav>.md-nav__list {
    -webkit-backface-visibility: hidden;
            backface-visibility: hidden;
  }
}
@media screen and (max-width: 59.9375em) {
  .md-nav--primary .md-nav__link[for=__toc] {
    display: flex;
  }
  .md-nav--primary .md-nav__link[for=__toc] .md-icon::after {
    content: "";
  }
  .md-nav--primary .md-nav__link[for=__toc]+.md-nav__link {
    display: none;
  }
  .md-nav--primary .md-nav__link[for=__toc]~.md-nav {
    display: flex;
  }
  .md-nav__source {
    display: block;
    padding: 0 0.2rem;
    color: var(--md-primary-bg-color);
    background-color: var(--md-primary-fg-color--dark);
  }
}
@media screen and (min-width: 60em) and (max-width: 76.1875em) {
  .md-nav--integrated .md-nav__link[for=__toc] {
    display: flex;
  }
  .md-nav--integrated .md-nav__link[for=__toc] .md-icon::after {
    content: "";
  }
  .md-nav--integrated .md-nav__link[for=__toc]+.md-nav__link {
    display: none;
  }
  .md-nav--integrated .md-nav__link[for=__toc]~.md-nav {
    display: flex;
  }
}
@media screen and (min-width: 60em) {
  .md-nav--secondary .md-nav__title {
    position: -webkit-sticky;
    position: sticky;
    top: 0;
    z-index: 1;
    background: var(--md-default-bg-color);
    box-shadow: 0 0 0.4rem 0.4rem var(--md-default-bg-color);
  }
  .md-nav--secondary .md-nav__title[for=__toc] {
    scroll-snap-align: start;
  }
  .md-nav--secondary .md-nav__title .md-nav__icon {
    display: none;
  }
}
@media screen and (min-width: 76.25em) {
  .md-nav {
    transition: max-height 250ms cubic-bezier(0.86, 0, 0.07, 1);
  }
  .md-nav--primary .md-nav__title {
    position: -webkit-sticky;
    position: sticky;
    top: 0;
    z-index: 1;
    background: var(--md-default-bg-color);
    box-shadow: 0 0 0.4rem 0.4rem var(--md-default-bg-color);
  }
  .md-nav--primary .md-nav__title[for=__drawer] {
    scroll-snap-align: start;
  }
  .md-nav--primary .md-nav__title .md-nav__icon {
    display: none;
  }
  .md-nav__toggle~.md-nav {
    display: none;
  }
  .md-nav__toggle:checked~.md-nav,.md-nav__toggle:indeterminate~.md-nav {
    display: block;
  }
  .md-nav__item--nested>.md-nav>.md-nav__title {
    display: none;
  }
  .md-nav__item--section {
    display: block;
    margin: 1.25em 0;
  }
  .md-nav__item--section:last-child {
    margin-bottom: 0;
  }
  .md-nav__item--section>.md-nav__link {
    font-weight: 700;
    pointer-events: none;
  }
  .md-nav__item--section>.md-nav__link[for] {
    color: var(--md-default-fg-color--light);
  }
  .md-nav__item--section>.md-nav__link--index [href] {
    pointer-events: initial;
  }
  .md-nav__item--section>.md-nav__link .md-nav__icon {
    display: none;
  }
  .md-nav__item--section>.md-nav {
    display: block;
  }
  .md-nav__item--section>.md-nav>.md-nav__list>.md-nav__item {
    padding: 0;
  }
  .md-nav__icon {
    width: 0.9rem;
    height: 0.9rem;
    border-radius: 100%;
    transition: background-color 250ms, transform 250ms;
  }
  [dir=rtl] .md-nav__icon {
    transform: rotate(180deg);
  }
  .md-nav__icon:hover {
    background-color: var(--md-accent-fg-color--transparent);
  }
  .md-nav__icon::after {
    display: inline-block;
    width: 100%;
    height: 100%;
    vertical-align: -0.1rem;
    background-color: currentcolor;
    -webkit-mask-image: var(--md-nav-icon--next);
            mask-image: var(--md-nav-icon--next);
    -webkit-mask-position: center;
            mask-position: center;
    -webkit-mask-repeat: no-repeat;
            mask-repeat: no-repeat;
    -webkit-mask-size: contain;
            mask-size: contain;
    content: "";
  }
  .md-nav__item--nested .md-nav__toggle:checked~.md-nav__link .md-nav__icon,.md-nav__item--nested .md-nav__toggle:indeterminate~.md-nav__link .md-nav__icon {
    transform: rotate(90deg);
  }
  .md-nav--lifted>.md-nav__list>.md-nav__item--nested,.md-nav--lifted>.md-nav__title {
    display: none;
  }
  .md-nav--lifted>.md-nav__list>.md-nav__item {
    display: none;
  }
  .md-nav--lifted>.md-nav__list>.md-nav__item--active {
    display: block;
    padding: 0;
  }
  .md-nav--lifted>.md-nav__list>.md-nav__item--active>.md-nav__link {
    position: -webkit-sticky;
    position: sticky;
    top: 0;
    z-index: 1;
    margin-top: 0;
    padding: 0 0.6rem;
    font-weight: 700;
    background: var(--md-default-bg-color);
    box-shadow: 0 0 0.4rem 0.4rem var(--md-default-bg-color);
  }
  .md-nav--lifted>.md-nav__list>.md-nav__item--active>.md-nav__link:not(.md-nav__link--index) {
    pointer-events: none;
  }
  .md-nav--lifted>.md-nav__list>.md-nav__item--active>.md-nav__link .md-nav__icon {
    display: none;
  }
  .md-nav--lifted>.md-nav__list>.md-nav__item>[for] {
    color: var(--md-default-fg-color--light);
  }
  .md-nav--lifted .md-nav[data-md-level="1"] {
    display: block;
  }
  [dir="ltr"] .md-nav--lifted .md-nav[data-md-level="1"]>.md-nav__list>.md-nav__item{
    padding-right: 0.6rem;
  }
  [dir="rtl"] .md-nav--lifted .md-nav[data-md-level="1"]>.md-nav__list>.md-nav__item{
    padding-left: 0.6rem;
  }
  .md-nav--integrated>.md-nav__list>.md-nav__item--active:not(.md-nav__item--nested) {
    padding: 0 0.6rem;
  }
  .md-nav--integrated>.md-nav__list>.md-nav__item--active:not(.md-nav__item--nested)>.md-nav__link {
    padding: 0;
  }
  [dir="ltr"] .md-nav--integrated>.md-nav__list>.md-nav__item--active .md-nav--secondary{
    border-left: 0.05rem solid var(--md-primary-fg-color);
  }
  [dir="rtl"] .md-nav--integrated>.md-nav__list>.md-nav__item--active .md-nav--secondary{
    border-right: 0.05rem solid var(--md-primary-fg-color);
  }
  .md-nav--integrated>.md-nav__list>.md-nav__item--active .md-nav--secondary {
    display: block;
    margin-bottom: 1.25em;
  }
  .md-nav--integrated>.md-nav__list>.md-nav__item--active .md-nav--secondary>.md-nav__title {
    display: none;
  }
}

:root {
  --md-search-result-icon: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M14 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h7c-.41-.25-.8-.56-1.14-.9-.33-.33-.61-.7-.86-1.1H6V4h7v5h5v1.18c.71.16 1.39.43 2 .82V8l-6-6m6.31 16.9c1.33-2.11.69-4.9-1.4-6.22-2.11-1.33-4.91-.68-6.22 1.4-1.34 2.11-.69 4.89 1.4 6.22 1.46.93 3.32.93 4.79.02L22 23.39 23.39 22l-3.08-3.1m-3.81.1a2.5 2.5 0 0 1-2.5-2.5 2.5 2.5 0 0 1 2.5-2.5 2.5 2.5 0 0 1 2.5 2.5 2.5 2.5 0 0 1-2.5 2.5Z'/></svg>");
}

.md-search {
  position: relative;
}
@media screen and (min-width: 60em) {
  .md-search {
    padding: 0.2rem 0;
  }
}
.no-js .md-search {
  display: none;
}
.md-search__overlay {
  z-index: 1;
  opacity: 0;
}
@media screen and (max-width: 59.9375em) {
  [dir="ltr"] .md-search__overlay{
    left: -2.2rem;
  }
  [dir="rtl"] .md-search__overlay{
    right: -2.2rem;
  }
  .md-search__overlay {
    position: absolute;
    top: -1rem;
    width: 2rem;
    height: 2rem;
    overflow: hidden;
    background-color: var(--md-default-bg-color);
    border-radius: 1rem;
    transform-origin: center;
    transition: transform 300ms 100ms, opacity 200ms 200ms;
    pointer-events: none;
  }
  [data-md-toggle=search]:checked~.md-header .md-search__overlay {
    opacity: 1;
    transition: transform 400ms, opacity 100ms;
  }
}
@media screen and (min-width: 60em) {
  [dir="ltr"] .md-search__overlay{
    left: 0;
  }
  [dir="rtl"] .md-search__overlay{
    right: 0;
  }
  .md-search__overlay {
    position: fixed;
    top: 0;
    width: 0;
    height: 0;
    background-color: hsla(0deg, 0%, 0%, 0.54);
    cursor: pointer;
    transition: width 0ms 250ms, height 0ms 250ms, opacity 250ms;
  }
  [data-md-toggle=search]:checked~.md-header .md-search__overlay {
    width: 100%;
    height: 200vh;
    opacity: 1;
    transition: width 0ms, height 0ms, opacity 250ms;
  }
}
@media screen and (max-width: 29.9375em) {
  [data-md-toggle=search]:checked~.md-header .md-search__overlay {
    transform: scale(45);
  }
}
@media screen and (min-width: 30em) and (max-width: 44.9375em) {
  [data-md-toggle=search]:checked~.md-header .md-search__overlay {
    transform: scale(60);
  }
}
@media screen and (min-width: 45em) and (max-width: 59.9375em) {
  [data-md-toggle=search]:checked~.md-header .md-search__overlay {
    transform: scale(75);
  }
}
.md-search__inner {
  -webkit-backface-visibility: hidden;
          backface-visibility: hidden;
}
@media screen and (max-width: 59.9375em) {
  [dir="ltr"] .md-search__inner{
    left: 0;
  }
  [dir="rtl"] .md-search__inner{
    right: 0;
  }
  .md-search__inner {
    position: fixed;
    top: 0;
    z-index: 2;
    width: 0;
    height: 0;
    overflow: hidden;
    transform: translateX(5%);
    opacity: 0;
    transition: width 0ms 300ms, height 0ms 300ms, transform 150ms 150ms cubic-bezier(0.4, 0, 0.2, 1), opacity 150ms 150ms;
  }
  [dir=rtl] .md-search__inner {
    transform: translateX(-5%);
  }
  [data-md-toggle=search]:checked~.md-header .md-search__inner {
    width: 100%;
    height: 100%;
    transform: translateX(0);
    opacity: 1;
    transition: width 0ms 0ms, height 0ms 0ms, transform 150ms 150ms cubic-bezier(0.1, 0.7, 0.1, 1), opacity 150ms 150ms;
  }
}
@media screen and (min-width: 60em) {
  [dir="ltr"] .md-search__inner{
    float: right;
  }
  [dir="rtl"] .md-search__inner{
    float: left;
  }
  .md-search__inner {
    position: relative;
    width: 11.7rem;
    padding: 0.1rem 0;
    transition: width 250ms cubic-bezier(0.1, 0.7, 0.1, 1);
  }
}
@media screen and (min-width: 60em) and (max-width: 76.1875em) {
  [data-md-toggle=search]:checked~.md-header .md-search__inner {
    width: 23.4rem;
  }
}
@media screen and (min-width: 76.25em) {
  [data-md-toggle=search]:checked~.md-header .md-search__inner {
    width: 34.4rem;
  }
}
.md-search__form {
  position: relative;
  z-index: 2;
  height: 2.4rem;
  background-color: var(--md-default-bg-color);
  box-shadow: 0 0 0.6rem transparent;
  transition: color 250ms, background-color 250ms;
}
@media screen and (min-width: 60em) {
  .md-search__form {
    height: 1.8rem;
    background-color: hsla(0deg, 0%, 0%, 0.26);
    border-radius: 0.1rem;
  }
  .md-search__form:hover {
    background-color: hsla(0deg, 0%, 100%, 0.12);
  }
}
[data-md-toggle=search]:checked~.md-header .md-search__form {
  color: var(--md-default-fg-color);
  background-color: var(--md-default-bg-color);
  border-radius: 0.1rem 0.1rem 0 0;
  box-shadow: 0 0 0.6rem hsla(0deg, 0%, 0%, 0.07);
}
[dir="ltr"] .md-search__input{
  padding-left: 3.6rem;
  padding-right: 2.2rem;
}
[dir="rtl"] .md-search__input{
  padding-right: 3.6rem;
  padding-left: 2.2rem;
}
.md-search__input {
  position: relative;
  z-index: 2;
  width: 100%;
  height: 100%;
  font-size: 0.9rem;
  text-overflow: ellipsis;
  background: transparent;
}
.md-search__input::placeholder {
  transition: color 250ms;
}
.md-search__input~.md-search__icon,.md-search__input::placeholder {
  color: var(--md-default-fg-color--light);
}
.md-search__input::-ms-clear {
  display: none;
}
@media screen and (max-width: 59.9375em) {
  .md-search__input {
    width: 100%;
    height: 2.4rem;
    font-size: 0.9rem;
  }
}
@media screen and (min-width: 60em) {
  [dir="ltr"] .md-search__input{
    padding-left: 2.2rem;
  }
  [dir="rtl"] .md-search__input{
    padding-right: 2.2rem;
  }
  .md-search__input {
    color: inherit;
    font-size: 0.8rem;
  }
  .md-search__input::placeholder {
    color: var(--md-primary-bg-color--light);
  }
  .md-search__input+.md-search__icon {
    color: var(--md-primary-bg-color);
  }
  [data-md-toggle=search]:checked~.md-header .md-search__input {
    text-overflow: clip;
  }
  [data-md-toggle=search]:checked~.md-header .md-search__input+.md-search__icon {
    color: var(--md-default-fg-color--light);
  }
  [data-md-toggle=search]:checked~.md-header .md-search__input::placeholder {
    color: transparent;
  }
}
.md-search__icon {
  display: inline-block;
  width: 1.2rem;
  height: 1.2rem;
  cursor: pointer;
  transition: color 250ms, opacity 250ms;
}
.md-search__icon:hover {
  opacity: 0.7;
}
[dir="ltr"] .md-search__icon[for=__search]{
  left: 0.5rem;
}
[dir="rtl"] .md-search__icon[for=__search]{
  right: 0.5rem;
}
.md-search__icon[for=__search] {
  position: absolute;
  top: 0.3rem;
  z-index: 2;
}
[dir=rtl] .md-search__icon[for=__search] svg {
  transform: scaleX(-1);
}
@media screen and (max-width: 59.9375em) {
  [dir="ltr"] .md-search__icon[for=__search]{
    left: 0.8rem;
  }
  [dir="rtl"] .md-search__icon[for=__search]{
    right: 0.8rem;
  }
  .md-search__icon[for=__search] {
    top: 0.6rem;
  }
  .md-search__icon[for=__search] svg:first-child {
    display: none;
  }
}
@media screen and (min-width: 60em) {
  .md-search__icon[for=__search] {
    pointer-events: none;
  }
  .md-search__icon[for=__search] svg:last-child {
    display: none;
  }
}
[dir="ltr"] .md-search__options{
  right: 0.5rem;
}
[dir="rtl"] .md-search__options{
  left: 0.5rem;
}
.md-search__options {
  position: absolute;
  top: 0.3rem;
  z-index: 2;
  pointer-events: none;
}
@media screen and (max-width: 59.9375em) {
  [dir="ltr"] .md-search__options{
    right: 0.8rem;
  }
  [dir="rtl"] .md-search__options{
    left: 0.8rem;
  }
  .md-search__options {
    top: 0.6rem;
  }
}
[dir="ltr"] .md-search__options>.md-icon{
  margin-left: 0.2rem;
}
[dir="rtl"] .md-search__options>.md-icon{
  margin-right: 0.2rem;
}
.md-search__options>.md-icon {
  color: var(--md-default-fg-color--light);
  transform: scale(0.75);
  opacity: 0;
  transition: transform 150ms cubic-bezier(0.1, 0.7, 0.1, 1), opacity 150ms;
}
.md-search__options>.md-icon:not(.focus-visible) {
  outline: none;
  -webkit-tap-highlight-color: transparent;
}
[data-md-toggle=search]:checked~.md-header .md-search__input:valid~.md-search__options>.md-icon {
  transform: scale(1);
  opacity: 1;
  pointer-events: initial;
}
[data-md-toggle=search]:checked~.md-header .md-search__input:valid~.md-search__options>.md-icon:hover {
  opacity: 0.7;
}
[dir="ltr"] .md-search__suggest{
  padding-left: 3.6rem;
  padding-right: 2.2rem;
}
[dir="rtl"] .md-search__suggest{
  padding-right: 3.6rem;
  padding-left: 2.2rem;
}
.md-search__suggest {
  position: absolute;
  top: 0;
  display: flex;
  align-items: center;
  width: 100%;
  height: 100%;
  color: var(--md-default-fg-color--lighter);
  font-size: 0.9rem;
  white-space: nowrap;
  opacity: 0;
  transition: opacity 50ms;
}
@media screen and (min-width: 60em) {
  [dir="ltr"] .md-search__suggest{
    padding-left: 2.2rem;
  }
  [dir="rtl"] .md-search__suggest{
    padding-right: 2.2rem;
  }
  .md-search__suggest {
    font-size: 0.8rem;
  }
}
[data-md-toggle=search]:checked~.md-header .md-search__suggest {
  opacity: 1;
  transition: opacity 300ms 100ms;
}
[dir="ltr"] .md-search__output{
  border-bottom-left-radius: 0.1rem;
}
[dir="rtl"] .md-search__output{
  border-bottom-right-radius: 0.1rem;
}
[dir="ltr"] .md-search__output{
  border-bottom-right-radius: 0.1rem;
}
[dir="rtl"] .md-search__output{
  border-bottom-left-radius: 0.1rem;
}
.md-search__output {
  position: absolute;
  z-index: 1;
  width: 100%;
  overflow: hidden;
}
@media screen and (max-width: 59.9375em) {
  .md-search__output {
    top: 2.4rem;
    bottom: 0;
  }
}
@media screen and (min-width: 60em) {
  .md-search__output {
    top: 1.9rem;
    opacity: 0;
    transition: opacity 400ms;
  }
  [data-md-toggle=search]:checked~.md-header .md-search__output {
    box-shadow: var(--md-shadow-z3);
    opacity: 1;
  }
}
.md-search__scrollwrap {
  height: 100%;
  overflow-y: auto;
  background-color: var(--md-default-bg-color);
  -webkit-backface-visibility: hidden;
          backface-visibility: hidden;
  touch-action: pan-y;
}
@media (-webkit-max-device-pixel-ratio: 1), (max-resolution: 1dppx) {
  .md-search__scrollwrap {
    transform: translateZ(0);
  }
}
@media screen and (min-width: 60em) and (max-width: 76.1875em) {
  .md-search__scrollwrap {
    width: 23.4rem;
  }
}
@media screen and (min-width: 76.25em) {
  .md-search__scrollwrap {
    width: 34.4rem;
  }
}
@media screen and (min-width: 60em) {
  .md-search__scrollwrap {
    max-height: 0;
    scrollbar-width: thin;
    scrollbar-color: var(--md-default-fg-color--lighter) transparent;
  }
  [data-md-toggle=search]:checked~.md-header .md-search__scrollwrap {
    max-height: 75vh;
  }
  .md-search__scrollwrap:hover {
    scrollbar-color: var(--md-accent-fg-color) transparent;
  }
  .md-search__scrollwrap::-webkit-scrollbar {
    width: 0.2rem;
    height: 0.2rem;
  }
  .md-search__scrollwrap::-webkit-scrollbar-thumb {
    background-color: var(--md-default-fg-color--lighter);
  }
  .md-search__scrollwrap::-webkit-scrollbar-thumb:hover {
    background-color: var(--md-accent-fg-color);
  }
}

.md-search-result {
  color: var(--md-default-fg-color);
  word-break: break-word;
}
.md-search-result__meta {
  padding: 0 0.8rem;
  color: var(--md-default-fg-color--light);
  font-size: 0.64rem;
  line-height: 1.8rem;
  background-color: var(--md-default-fg-color--lightest);
  scroll-snap-align: start;
}
@media screen and (min-width: 60em) {
  [dir="ltr"] .md-search-result__meta{
    padding-left: 2.2rem;
  }
  [dir="rtl"] .md-search-result__meta{
    padding-right: 2.2rem;
  }
}
.md-search-result__list {
  margin: 0;
  padding: 0;
  list-style: none;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}
.md-search-result__item {
  box-shadow: 0 -0.05rem var(--md-default-fg-color--lightest);
}
.md-search-result__item:first-child {
  box-shadow: none;
}
.md-search-result__link {
  display: block;
  outline: none;
  transition: background-color 250ms;
  scroll-snap-align: start;
}
.md-search-result__link:focus,.md-search-result__link:hover {
  background-color: var(--md-accent-fg-color--transparent);
}
.md-search-result__link:last-child p:last-child {
  margin-bottom: 0.6rem;
}
.md-search-result__more>summary {
  position: -webkit-sticky;
  position: sticky;
  top: 0;
  z-index: 1;
  display: block;
  outline: none;
  cursor: pointer;
  scroll-snap-align: start;
}
.md-search-result__more>summary::marker {
  display: none;
}
.md-search-result__more>summary::-webkit-details-marker {
  display: none;
}
.md-search-result__more>summary>div {
  padding: 0.75em 0.8rem;
  color: var(--md-typeset-a-color);
  font-size: 0.64rem;
  transition: color 250ms, background-color 250ms;
}
@media screen and (min-width: 60em) {
  [dir="ltr"] .md-search-result__more>summary>div{
    padding-left: 2.2rem;
  }
  [dir="rtl"] .md-search-result__more>summary>div{
    padding-right: 2.2rem;
  }
}
.md-search-result__more>summary:focus>div,.md-search-result__more>summary:hover>div {
  color: var(--md-accent-fg-color);
  background-color: var(--md-accent-fg-color--transparent);
}
.md-search-result__more[open]>summary {
  background-color: var(--md-default-bg-color);
}
.md-search-result__article {
  position: relative;
  padding: 0 0.8rem;
  overflow: hidden;
}
@media screen and (min-width: 60em) {
  [dir="ltr"] .md-search-result__article{
    padding-left: 2.2rem;
  }
  [dir="rtl"] .md-search-result__article{
    padding-right: 2.2rem;
  }
}
[dir="ltr"] .md-search-result__icon{
  left: 0;
}
[dir="rtl"] .md-search-result__icon{
  right: 0;
}
.md-search-result__icon {
  position: absolute;
  width: 1.2rem;
  height: 1.2rem;
  margin: 0.5rem;
  color: var(--md-default-fg-color--light);
}
@media screen and (max-width: 59.9375em) {
  .md-search-result__icon {
    display: none;
  }
}
.md-search-result__icon::after {
  display: inline-block;
  width: 100%;
  height: 100%;
  background-color: currentcolor;
  -webkit-mask-image: var(--md-search-result-icon);
          mask-image: var(--md-search-result-icon);
  -webkit-mask-position: center;
          mask-position: center;
  -webkit-mask-repeat: no-repeat;
          mask-repeat: no-repeat;
  -webkit-mask-size: contain;
          mask-size: contain;
  content: "";
}
[dir=rtl] .md-search-result__icon::after {
  transform: scaleX(-1);
}
.md-search-result .md-typeset {
  color: var(--md-default-fg-color--light);
  font-size: 0.64rem;
  line-height: 1.6;
}
.md-search-result .md-typeset h1 {
  margin: 0.55rem 0;
  color: var(--md-default-fg-color);
  font-weight: 400;
  font-size: 0.8rem;
  line-height: 1.4;
}
.md-search-result .md-typeset h1 mark {
  text-decoration: none;
}
.md-search-result .md-typeset h2 {
  margin: 0.5em 0;
  color: var(--md-default-fg-color);
  font-weight: 700;
  font-size: 0.64rem;
  line-height: 1.6;
}
.md-search-result .md-typeset h2 mark {
  text-decoration: none;
}
.md-search-result__terms {
  display: block;
  margin: 0.5em 0;
  color: var(--md-default-fg-color);
  font-size: 0.64rem;
  font-style: italic;
}
.md-search-result mark {
  color: var(--md-accent-fg-color);
  text-decoration: underline;
  background-color: transparent;
}

.md-select {
  position: relative;
  z-index: 1;
}
.md-select__inner {
  position: absolute;
  top: calc(100% - 0.2rem);
  left: 50%;
  max-height: 0;
  margin-top: 0.2rem;
  color: var(--md-default-fg-color);
  background-color: var(--md-default-bg-color);
  border-radius: 0.1rem;
  box-shadow: var(--md-shadow-z2);
  transform: translate3d(-50%, 0.3rem, 0);
  opacity: 0;
  transition: transform 250ms 375ms, opacity 250ms 250ms, max-height 0ms 500ms;
}
.md-select:focus-within .md-select__inner,.md-select:hover .md-select__inner {
  max-height: 10rem;
  transform: translate3d(-50%, 0, 0);
  opacity: 1;
  transition: transform 250ms cubic-bezier(0.1, 0.7, 0.1, 1), opacity 250ms, max-height 0ms;
}
.md-select__inner::after {
  position: absolute;
  top: 0;
  left: 50%;
  width: 0;
  height: 0;
  margin-top: -0.2rem;
  margin-left: -0.2rem;
  border: 0.2rem solid transparent;
  border-top: 0;
  border-bottom-color: var(--md-default-bg-color);
  content: "";
}
.md-select__list {
  max-height: inherit;
  margin: 0;
  padding: 0;
  overflow: auto;
  font-size: 0.8rem;
  list-style-type: none;
  border-radius: 0.1rem;
}
.md-select__item {
  line-height: 1.8rem;
}
[dir="ltr"] .md-select__link{
  padding-left: 0.6rem;
  padding-right: 1.2rem;
}
[dir="rtl"] .md-select__link{
  padding-right: 0.6rem;
  padding-left: 1.2rem;
}
.md-select__link {
  display: block;
  width: 100%;
  outline: none;
  cursor: pointer;
  transition: background-color 250ms, color 250ms;
  scroll-snap-align: start;
}
.md-select__link:focus,.md-select__link:hover {
  color: var(--md-accent-fg-color);
}
.md-select__link:focus {
  background-color: var(--md-default-fg-color--lightest);
}

.md-sidebar {
  position: -webkit-sticky;
  position: sticky;
  top: 2.4rem;
  flex-shrink: 0;
  align-self: flex-start;
  width: 12.1rem;
  padding: 1.2rem 0;
}
@media print {
  .md-sidebar {
    display: none;
  }
}
@media screen and (max-width: 76.1875em) {
  [dir="ltr"] .md-sidebar--primary{
    left: -12.1rem;
  }
  [dir="rtl"] .md-sidebar--primary{
    right: -12.1rem;
  }
  .md-sidebar--primary {
    position: fixed;
    top: 0;
    z-index: 5;
    display: block;
    width: 12.1rem;
    height: 100%;
    background-color: var(--md-default-bg-color);
    transform: translateX(0);
    transition: transform 250ms cubic-bezier(0.4, 0, 0.2, 1), box-shadow 250ms;
  }
  [data-md-toggle=drawer]:checked~.md-container .md-sidebar--primary {
    box-shadow: var(--md-shadow-z3);
    transform: translateX(12.1rem);
  }
  [dir=rtl] [data-md-toggle=drawer]:checked~.md-container .md-sidebar--primary {
    transform: translateX(-12.1rem);
  }
  .md-sidebar--primary .md-sidebar__scrollwrap {
    position: absolute;
    top: 0;
    right: 0;
    bottom: 0;
    left: 0;
    margin: 0;
    scroll-snap-type: none;
    overflow: hidden;
  }
}
@media screen and (min-width: 76.25em) {
  .md-sidebar {
    height: 0;
  }
  .no-js .md-sidebar {
    height: auto;
  }
  .md-header--lifted~.md-container .md-sidebar {
    top: 4.8rem;
  }
}
.md-sidebar--secondary {
  display: none;
  order: 2;
}
@media screen and (min-width: 60em) {
  .md-sidebar--secondary {
    height: 0;
  }
  .no-js .md-sidebar--secondary {
    height: auto;
  }
  .md-sidebar--secondary:not([hidden]) {
    display: block;
  }
  .md-sidebar--secondary .md-sidebar__scrollwrap {
    touch-action: pan-y;
  }
}
.md-sidebar__scrollwrap {
  margin: 0 0.2rem;
  overflow-y: auto;
  -webkit-backface-visibility: hidden;
          backface-visibility: hidden;
  scrollbar-width: thin;
  scrollbar-gutter: stable;
  scrollbar-color: var(--md-default-fg-color--lighter) transparent;
}
.md-sidebar__scrollwrap::-webkit-scrollbar {
  width: 0.2rem;
  height: 0.2rem;
}
.md-sidebar__scrollwrap:focus-within,.md-sidebar__scrollwrap:hover {
  scrollbar-color: var(--md-accent-fg-color) transparent;
}
.md-sidebar__scrollwrap:focus-within::-webkit-scrollbar-thumb,.md-sidebar__scrollwrap:hover::-webkit-scrollbar-thumb {
  background-color: var(--md-default-fg-color--lighter);
}
.md-sidebar__scrollwrap:focus-within::-webkit-scrollbar-thumb:hover,.md-sidebar__scrollwrap:hover::-webkit-scrollbar-thumb:hover {
  background-color: var(--md-accent-fg-color);
}
@supports selector(::-webkit-scrollbar) {
  .md-sidebar__scrollwrap {
    scrollbar-gutter: auto;
  }
  [dir="ltr"] .md-sidebar__inner{
    padding-right: calc(100% - 11.5rem);
  }
  [dir="rtl"] .md-sidebar__inner{
    padding-left: calc(100% - 11.5rem);
  }
}

@media screen and (max-width: 76.1875em) {
  .md-overlay {
    position: fixed;
    top: 0;
    z-index: 5;
    width: 0;
    height: 0;
    background-color: hsla(0deg, 0%, 0%, 0.54);
    opacity: 0;
    transition: width 0ms 250ms, height 0ms 250ms, opacity 250ms;
  }
  [data-md-toggle=drawer]:checked~.md-overlay {
    width: 100%;
    height: 100%;
    opacity: 1;
    transition: width 0ms, height 0ms, opacity 250ms;
  }
}
@keyframes facts {
  0% {
    height: 0;
  }
  100% {
    height: 0.65rem;
  }
}
@keyframes fact {
  0% {
    transform: translateY(100%);
    opacity: 0;
  }
  50% {
    opacity: 0;
  }
  100% {
    transform: translateY(0%);
    opacity: 1;
  }
}
:root {
  --md-source-forks-icon: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16'><path d='M5 5.372v.878c0 .414.336.75.75.75h4.5a.75.75 0 0 0 .75-.75v-.878a2.25 2.25 0 1 1 1.5 0v.878a2.25 2.25 0 0 1-2.25 2.25h-1.5v2.128a2.251 2.251 0 1 1-1.5 0V8.5h-1.5A2.25 2.25 0 0 1 3.5 6.25v-.878a2.25 2.25 0 1 1 1.5 0ZM5 3.25a.75.75 0 1 0-1.5 0 .75.75 0 0 0 1.5 0Zm6.75.75a.75.75 0 1 0 0-1.5.75.75 0 0 0 0 1.5Zm-3 8.75a.75.75 0 1 0-1.5 0 .75.75 0 0 0 1.5 0Z'/></svg>");
  --md-source-repositories-icon: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16'><path d='M2 2.5A2.5 2.5 0 0 1 4.5 0h8.75a.75.75 0 0 1 .75.75v12.5a.75.75 0 0 1-.75.75h-2.5a.75.75 0 0 1 0-1.5h1.75v-2h-8a1 1 0 0 0-.714 1.7.75.75 0 1 1-1.072 1.05A2.495 2.495 0 0 1 2 11.5Zm10.5-1h-8a1 1 0 0 0-1 1v6.708A2.486 2.486 0 0 1 4.5 9h8ZM5 12.25a.25.25 0 0 1 .25-.25h3.5a.25.25 0 0 1 .25.25v3.25a.25.25 0 0 1-.4.2l-1.45-1.087a.249.249 0 0 0-.3 0L5.4 15.7a.25.25 0 0 1-.4-.2Z'/></svg>");
  --md-source-stars-icon: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16'><path d='M8 .25a.75.75 0 0 1 .673.418l1.882 3.815 4.21.612a.75.75 0 0 1 .416 1.279l-3.046 2.97.719 4.192a.751.751 0 0 1-1.088.791L8 12.347l-3.766 1.98a.75.75 0 0 1-1.088-.79l.72-4.194L.818 6.374a.75.75 0 0 1 .416-1.28l4.21-.611L7.327.668A.75.75 0 0 1 8 .25Zm0 2.445L6.615 5.5a.75.75 0 0 1-.564.41l-3.097.45 2.24 2.184a.75.75 0 0 1 .216.664l-.528 3.084 2.769-1.456a.75.75 0 0 1 .698 0l2.77 1.456-.53-3.084a.75.75 0 0 1 .216-.664l2.24-2.183-3.096-.45a.75.75 0 0 1-.564-.41L8 2.694Z'/></svg>");
  --md-source-version-icon: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16'><path d='M1 7.775V2.75C1 1.784 1.784 1 2.75 1h5.025c.464 0 .91.184 1.238.513l6.25 6.25a1.75 1.75 0 0 1 0 2.474l-5.026 5.026a1.75 1.75 0 0 1-2.474 0l-6.25-6.25A1.752 1.752 0 0 1 1 7.775Zm1.5 0c0 .066.026.13.073.177l6.25 6.25a.25.25 0 0 0 .354 0l5.025-5.025a.25.25 0 0 0 0-.354l-6.25-6.25a.25.25 0 0 0-.177-.073H2.75a.25.25 0 0 0-.25.25ZM6 5a1 1 0 1 1 0 2 1 1 0 0 1 0-2Z'/></svg>");
}

.md-source {
  display: block;
  font-size: 0.65rem;
  line-height: 1.2;
  white-space: nowrap;
  outline-color: var(--md-accent-fg-color);
  -webkit-backface-visibility: hidden;
          backface-visibility: hidden;
  transition: opacity 250ms;
}
.md-source:hover {
  opacity: 0.7;
}
.md-source__icon {
  display: inline-block;
  width: 2rem;
  height: 2.4rem;
  vertical-align: middle;
}
[dir="ltr"] .md-source__icon svg{
  margin-left: 0.6rem;
}
[dir="rtl"] .md-source__icon svg{
  margin-right: 0.6rem;
}
.md-source__icon svg {
  margin-top: 0.6rem;
}
[dir="ltr"] .md-source__icon+.md-source__repository{
  margin-left: -2rem;
}
[dir="rtl"] .md-source__icon+.md-source__repository{
  margin-right: -2rem;
}
[dir="ltr"] .md-source__icon+.md-source__repository{
  padding-left: 2rem;
}
[dir="rtl"] .md-source__icon+.md-source__repository{
  padding-right: 2rem;
}
[dir="ltr"] .md-source__repository{
  margin-left: 0.6rem;
}
[dir="rtl"] .md-source__repository{
  margin-right: 0.6rem;
}
.md-source__repository {
  display: inline-block;
  max-width: calc(100% - 1.2rem);
  overflow: hidden;
  text-overflow: ellipsis;
  vertical-align: middle;
}
.md-source__facts {
  display: flex;
  gap: 0.4rem;
  width: 100%;
  margin: 0.1rem 0 0;
  padding: 0;
  overflow: hidden;
  font-size: 0.55rem;
  list-style-type: none;
  opacity: 0.75;
}
.md-source__repository--active .md-source__facts {
  animation: facts 250ms ease-in;
}
.md-source__fact {
  overflow: hidden;
  text-overflow: ellipsis;
}
.md-source__repository--active .md-source__fact {
  animation: fact 400ms ease-out;
}
[dir="ltr"] .md-source__fact::before{
  margin-right: 0.1rem;
}
[dir="rtl"] .md-source__fact::before{
  margin-left: 0.1rem;
}
.md-source__fact::before {
  display: inline-block;
  width: 0.6rem;
  height: 0.6rem;
  vertical-align: text-top;
  background-color: currentcolor;
  -webkit-mask-position: center;
          mask-position: center;
  -webkit-mask-repeat: no-repeat;
          mask-repeat: no-repeat;
  -webkit-mask-size: contain;
          mask-size: contain;
  content: "";
}
.md-source__fact:nth-child(1n+2) {
  flex-shrink: 0;
}
.md-source__fact--version::before {
  -webkit-mask-image: var(--md-source-version-icon);
          mask-image: var(--md-source-version-icon);
}
.md-source__fact--stars::before {
  -webkit-mask-image: var(--md-source-stars-icon);
          mask-image: var(--md-source-stars-icon);
}
.md-source__fact--forks::before {
  -webkit-mask-image: var(--md-source-forks-icon);
          mask-image: var(--md-source-forks-icon);
}
.md-source__fact--repositories::before {
  -webkit-mask-image: var(--md-source-repositories-icon);
          mask-image: var(--md-source-repositories-icon);
}

.md-tabs {
  z-index: 3;
  display: block;
  width: 100%;
  overflow: auto;
  color: var(--md-primary-bg-color);
  line-height: 1.3;
  background-color: var(--md-primary-fg-color);
}
@media print {
  .md-tabs {
    display: none;
  }
}
@media screen and (max-width: 76.1875em) {
  .md-tabs {
    display: none;
  }
}
.md-tabs[hidden] {
  pointer-events: none;
}
[dir="ltr"] .md-tabs__list{
  margin-left: 0.2rem;
}
[dir="rtl"] .md-tabs__list{
  margin-right: 0.2rem;
}
.md-tabs__list {
  margin: 0;
  padding: 0;
  overflow: auto;
  white-space: nowrap;
  list-style: none;
  contain: content;
  scrollbar-width: none;
}
.md-tabs__list::-webkit-scrollbar {
  display: none;
}
.md-tabs__item {
  display: inline-block;
  height: 2.4rem;
  padding-left: 0.6rem;
  padding-right: 0.6rem;
}
.md-tabs__link {
  display: block;
  margin-top: 0.8rem;
  font-size: 0.7rem;
  outline-color: var(--md-accent-fg-color);
  outline-offset: 0.2rem;
  -webkit-backface-visibility: hidden;
          backface-visibility: hidden;
  opacity: 0.7;
  transition: transform 400ms cubic-bezier(0.1, 0.7, 0.1, 1), opacity 250ms;
}
.md-tabs__link--active,.md-tabs__link:focus,.md-tabs__link:hover {
  color: inherit;
  opacity: 1;
}
.md-tabs__item:nth-child(2) .md-tabs__link {
  transition-delay: 20ms;
}
.md-tabs__item:nth-child(3) .md-tabs__link {
  transition-delay: 40ms;
}
.md-tabs__item:nth-child(4) .md-tabs__link {
  transition-delay: 60ms;
}
.md-tabs__item:nth-child(5) .md-tabs__link {
  transition-delay: 80ms;
}
.md-tabs__item:nth-child(6) .md-tabs__link {
  transition-delay: 100ms;
}
.md-tabs__item:nth-child(7) .md-tabs__link {
  transition-delay: 120ms;
}
.md-tabs__item:nth-child(8) .md-tabs__link {
  transition-delay: 140ms;
}
.md-tabs__item:nth-child(9) .md-tabs__link {
  transition-delay: 160ms;
}
.md-tabs__item:nth-child(10) .md-tabs__link {
  transition-delay: 180ms;
}
.md-tabs__item:nth-child(11) .md-tabs__link {
  transition-delay: 200ms;
}
.md-tabs__item:nth-child(12) .md-tabs__link {
  transition-delay: 220ms;
}
.md-tabs__item:nth-child(13) .md-tabs__link {
  transition-delay: 240ms;
}
.md-tabs__item:nth-child(14) .md-tabs__link {
  transition-delay: 260ms;
}
.md-tabs__item:nth-child(15) .md-tabs__link {
  transition-delay: 280ms;
}
.md-tabs__item:nth-child(16) .md-tabs__link {
  transition-delay: 300ms;
}
.md-tabs[hidden] .md-tabs__link {
  transform: translateY(50%);
  opacity: 0;
  transition: transform 0ms 100ms, opacity 100ms;
}

:root {
  --md-tag-icon: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='m5.41 21 .71-4h-4l.35-2h4l1.06-6h-4l.35-2h4l.71-4h2l-.71 4h6l.71-4h2l-.71 4h4l-.35 2h-4l-1.06 6h4l-.35 2h-4l-.71 4h-2l.71-4h-6l-.71 4h-2M9.53 9l-1.06 6h6l1.06-6h-6Z'/></svg>");
}

.md-typeset .md-tags {
  margin-top: -0.125em;
  margin-bottom: 0.75em;
}
[dir="ltr"] .md-typeset .md-tag{
  margin-right: 0.5em;
}
[dir="rtl"] .md-typeset .md-tag{
  margin-left: 0.5em;
}
.md-typeset .md-tag {
  display: inline-block;
  margin-bottom: 0.5em;
  padding: 0.3125em 0.9375em;
  font-weight: 700;
  font-size: 0.64rem;
  line-height: 1.6;
  letter-spacing: initial;
  vertical-align: middle;
  background: var(--md-default-fg-color--lightest);
  border-radius: 2.4rem;
}
.md-typeset .md-tag[href] {
  color: inherit;
  outline: none;
  -webkit-tap-highlight-color: transparent;
  transition: color 125ms, background-color 125ms;
}
.md-typeset .md-tag[href]:focus,.md-typeset .md-tag[href]:hover {
  color: var(--md-accent-bg-color);
  background-color: var(--md-accent-fg-color);
}
[id]>.md-typeset .md-tag {
  vertical-align: text-top;
}
.md-typeset .md-tag-icon::before {
  display: inline-block;
  width: 1.2em;
  height: 1.2em;
  margin-right: 0.4em;
  vertical-align: text-bottom;
  background-color: var(--md-default-fg-color--lighter);
  -webkit-mask-image: var(--md-tag-icon);
          mask-image: var(--md-tag-icon);
  -webkit-mask-position: center;
          mask-position: center;
  -webkit-mask-repeat: no-repeat;
          mask-repeat: no-repeat;
  -webkit-mask-size: contain;
          mask-size: contain;
  transition: background-color 125ms;
  content: "";
}
.md-typeset .md-tag-icon[href]:focus::before,.md-typeset .md-tag-icon[href]:hover::before {
  background-color: var(--md-accent-bg-color);
}

@keyframes pulse {
  0% {
    box-shadow: 0 0 0 0 var(--md-default-fg-color--lightest);
    transform: scale(0.95);
  }
  75% {
    box-shadow: 0 0 0 0.625em transparent;
    transform: scale(1);
  }
  100% {
    box-shadow: 0 0 0 0 transparent;
    transform: scale(0.95);
  }
}
:root {
  --md-tooltip-width: 20rem;
}

.md-tooltip {
  position: absolute;
  top: var(--md-tooltip-y);
  left: clamp(
      var(--md-tooltip-0, 0rem) + 0.8rem,
      var(--md-tooltip-x),
      100vw +
      var(--md-tooltip-0, 0rem) + 0.8rem -
      var(--md-tooltip-width) -
      2 * 0.8rem
    );
  z-index: 0;
  width: var(--md-tooltip-width);
  max-width: calc(100vw - 2 * 0.8rem);
  color: var(--md-default-fg-color);
  font-family: var(--md-text-font-family);
  background-color: var(--md-default-bg-color);
  border-radius: 0.1rem;
  box-shadow: var(--md-shadow-z2);
  transform: translateY(-0.4rem);
  -webkit-backface-visibility: hidden;
          backface-visibility: hidden;
  opacity: 0;
  transition: transform 0ms 250ms, opacity 250ms, z-index 250ms;
}
.md-tooltip--active {
  z-index: 2;
  transform: translateY(0);
  opacity: 1;
  transition: transform 250ms cubic-bezier(0.1, 0.7, 0.1, 1), opacity 250ms, z-index 0ms;
}
.focus-visible>.md-tooltip,.md-tooltip:target {
  outline: var(--md-accent-fg-color) auto;
}
.md-tooltip__inner {
  padding: 0.8rem;
  font-size: 0.64rem;
}
.md-tooltip__inner.md-typeset>:first-child {
  margin-top: 0;
}
.md-tooltip__inner.md-typeset>:last-child {
  margin-bottom: 0;
}

.md-annotation {
  font-weight: 400;
  white-space: normal;
  outline: none;
}
[dir=rtl] .md-annotation {
  direction: rtl;
}
.md-annotation:not([hidden]) {
  display: inline-block;
  line-height: 1.325;
}
.md-annotation__index {
  position: relative;
  z-index: 0;
  margin: 0 1ch;
  font-size: 0.85em;
  font-family: var(--md-code-font-family);
  outline: none;
  cursor: pointer;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}
.md-annotation .md-annotation__index {
  color: hsl(0deg, 0%, 100%);
  transition: z-index 250ms;
}
.md-annotation .md-annotation__index:focus,.md-annotation .md-annotation__index:hover {
  color: hsl(0deg, 0%, 100%);
}
.md-annotation__index::after {
  position: absolute;
  top: 0;
  left: -0.125em;
  z-index: -1;
  width: calc(100% + 1.2ch);
  width: max(2.2ch, 100% + 1.2ch);
  height: 2.2ch;
  margin: 0 -0.4ch;
  padding: 0 0.4ch;
  background-color: var(--md-default-fg-color--lighter);
  border-radius: 2ch;
  transition: color 250ms, background-color 250ms;
  content: "";
}
@media not all and (prefers-reduced-motion) {
  [data-md-visible]>.md-annotation__index::after {
    animation: pulse 2000ms infinite;
  }
}
.md-tooltip--active+.md-annotation__index::after {
  transition: color 250ms, background-color 250ms;
  animation: none;
}
code .md-annotation__index {
  font-size: inherit;
  font-family: var(--md-code-font-family);
}
.md-tooltip--active+.md-annotation__index,:hover>.md-annotation__index {
  color: var(--md-accent-bg-color);
}
.md-tooltip--active+.md-annotation__index::after,:hover>.md-annotation__index::after {
  background-color: var(--md-accent-fg-color);
}
.md-tooltip--active+.md-annotation__index {
  z-index: 2;
  transition: none;
  animation: none;
}
.md-annotation__index [data-md-annotation-id] {
  display: inline-block;
  line-height: 90%;
}
.md-annotation__index [data-md-annotation-id]::before {
  display: inline-block;
  padding-bottom: 0.1em;
  vertical-align: 0.065em;
  transform: scale(1.15);
  transition: transform 400ms cubic-bezier(0.1, 0.7, 0.1, 1);
  content: attr(data-md-annotation-id);
}
@media not print {
  .md-annotation__index [data-md-annotation-id]::before {
    content: "+";
  }
  :focus-within>.md-annotation__index [data-md-annotation-id]::before {
    transform: scale(1.25) rotate(45deg);
  }
}

[dir="ltr"] .md-top{
  margin-left: 50%;
}

[dir="rtl"] .md-top{
  margin-right: 50%;
}

.md-top {
  position: fixed;
  top: 3.2rem;
  z-index: 2;
  display: block;
  padding: 0.4rem 0.8rem;
  color: var(--md-default-fg-color--light);
  font-size: 0.7rem;
  background-color: var(--md-default-bg-color);
  border-radius: 1.6rem;
  outline: none;
  box-shadow: var(--md-shadow-z2);
  transform: translate(-50%, 0);
  transition: color 125ms, background-color 125ms, transform 125ms cubic-bezier(0.4, 0, 0.2, 1), opacity 125ms;
}
@media print {
  .md-top {
    display: none;
  }
}
[dir=rtl] .md-top {
  transform: translate(50%, 0);
}
.md-top[hidden] {
  transform: translate(-50%, 0.2rem);
  opacity: 0;
  transition-duration: 0ms;
  pointer-events: none;
}
[dir=rtl] .md-top[hidden] {
  transform: translate(50%, 0.2rem);
}
.md-top:focus,.md-top:hover {
  color: var(--md-accent-bg-color);
  background-color: var(--md-accent-fg-color);
}
.md-top svg {
  display: inline-block;
  vertical-align: -0.5em;
}

@keyframes hoverfix {
  0% {
    pointer-events: none;
  }
}
:root {
  --md-version-icon: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 320 512'><!--! Font Awesome Free 6.2.1 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license/free (Icons: CC BY 4.0, Fonts: SIL OFL 1.1, Code: MIT License) Copyright 2022 Fonticons, Inc.--><path d='M137.4 374.6c12.5 12.5 32.8 12.5 45.3 0l128-128c9.2-9.2 11.9-22.9 6.9-34.9S301 191.9 288 191.9L32 192c-12.9 0-24.6 7.8-29.6 19.8s-2.2 25.7 6.9 34.9l128 128z'/></svg>");
}

.md-version {
  flex-shrink: 0;
  height: 2.4rem;
  font-size: 0.8rem;
}
[dir="ltr"] .md-version__current{
  margin-left: 1.4rem;
  margin-right: 0.4rem;
}
[dir="rtl"] .md-version__current{
  margin-right: 1.4rem;
  margin-left: 0.4rem;
}
.md-version__current {
  position: relative;
  top: 0.05rem;
  color: inherit;
  outline: none;
  cursor: pointer;
}
[dir="ltr"] .md-version__current::after{
  margin-left: 0.4rem;
}
[dir="rtl"] .md-version__current::after{
  margin-right: 0.4rem;
}
.md-version__current::after {
  display: inline-block;
  width: 0.4rem;
  height: 0.6rem;
  background-color: currentcolor;
  -webkit-mask-image: var(--md-version-icon);
          mask-image: var(--md-version-icon);
  -webkit-mask-position: center;
          mask-position: center;
  -webkit-mask-repeat: no-repeat;
          mask-repeat: no-repeat;
  -webkit-mask-size: contain;
          mask-size: contain;
  content: "";
}
.md-version__list {
  position: absolute;
  top: 0.15rem;
  z-index: 3;
  max-height: 0;
  margin: 0.2rem 0.8rem;
  padding: 0;
  overflow: auto;
  color: var(--md-default-fg-color);
  list-style-type: none;
  background-color: var(--md-default-bg-color);
  border-radius: 0.1rem;
  box-shadow: var(--md-shadow-z2);
  opacity: 0;
  transition: max-height 0ms 500ms, opacity 250ms 250ms;
  scroll-snap-type: y mandatory;
}
.md-version:focus-within .md-version__list,.md-version:hover .md-version__list {
  max-height: 10rem;
  opacity: 1;
  transition: max-height 0ms, opacity 250ms;
}
@media (pointer: coarse) {
  .md-version:hover .md-version__list {
    animation: hoverfix 250ms forwards;
  }
  .md-version:focus-within .md-version__list {
    animation: none;
  }
}
.md-version__item {
  line-height: 1.8rem;
}
[dir="ltr"] .md-version__link{
  padding-left: 0.6rem;
  padding-right: 1.2rem;
}
[dir="rtl"] .md-version__link{
  padding-right: 0.6rem;
  padding-left: 1.2rem;
}
.md-version__link {
  display: block;
  width: 100%;
  white-space: nowrap;
  outline: none;
  cursor: pointer;
  transition: color 250ms, background-color 250ms;
  scroll-snap-align: start;
}
.md-version__link:focus,.md-version__link:hover {
  color: var(--md-accent-fg-color);
}
.md-version__link:focus {
  background-color: var(--md-default-fg-color--lightest);
}

:root {
  --md-admonition-icon--note:
    url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M12 2C6.47 2 2 6.47 2 12s4.47 10 10 10 10-4.47 10-10S17.53 2 12 2m3.1 5.07c.14 0 .28.05.4.16l1.27 1.27c.23.22.23.57 0 .78l-1 1-2.05-2.05 1-1c.1-.11.24-.16.38-.16m-1.97 1.74 2.06 2.06-6.06 6.06H7.07v-2.06l6.06-6.06Z'/></svg>");
  --md-admonition-icon--abstract:
    url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M17 9H7V7h10m0 6H7v-2h10m-3 6H7v-2h7M12 3a1 1 0 0 1 1 1 1 1 0 0 1-1 1 1 1 0 0 1-1-1 1 1 0 0 1 1-1m7 0h-4.18C14.4 1.84 13.3 1 12 1c-1.3 0-2.4.84-2.82 2H5a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h14a2 2 0 0 0 2-2V5a2 2 0 0 0-2-2Z'/></svg>");
  --md-admonition-icon--info:
    url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M13 9h-2V7h2m0 10h-2v-6h2m-1-9A10 10 0 0 0 2 12a10 10 0 0 0 10 10 10 10 0 0 0 10-10A10 10 0 0 0 12 2Z'/></svg>");
  --md-admonition-icon--tip:
    url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M17.66 11.2c-.23-.3-.51-.56-.77-.82-.67-.6-1.43-1.03-2.07-1.66C13.33 7.26 13 4.85 13.95 3c-.95.23-1.78.75-2.49 1.32-2.59 2.08-3.61 5.75-2.39 8.9.04.1.08.2.08.33 0 .22-.15.42-.35.5-.23.1-.47.04-.66-.12a.58.58 0 0 1-.14-.17c-1.13-1.43-1.31-3.48-.55-5.12C5.78 10 4.87 12.3 5 14.47c.06.5.12 1 .29 1.5.14.6.41 1.2.71 1.73 1.08 1.73 2.95 2.97 4.96 3.22 2.14.27 4.43-.12 6.07-1.6 1.83-1.66 2.47-4.32 1.53-6.6l-.13-.26c-.21-.46-.77-1.26-.77-1.26m-3.16 6.3c-.28.24-.74.5-1.1.6-1.12.4-2.24-.16-2.9-.82 1.19-.28 1.9-1.16 2.11-2.05.17-.8-.15-1.46-.28-2.23-.12-.74-.1-1.37.17-2.06.19.38.39.76.63 1.06.77 1 1.98 1.44 2.24 2.8.04.14.06.28.06.43.03.82-.33 1.72-.93 2.27Z'/></svg>");
  --md-admonition-icon--success:
    url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M21 7 9 19l-5.5-5.5 1.41-1.41L9 16.17 19.59 5.59 21 7Z'/></svg>");
  --md-admonition-icon--question:
    url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='m15.07 11.25-.9.92C13.45 12.89 13 13.5 13 15h-2v-.5c0-1.11.45-2.11 1.17-2.83l1.24-1.26c.37-.36.59-.86.59-1.41a2 2 0 0 0-2-2 2 2 0 0 0-2 2H8a4 4 0 0 1 4-4 4 4 0 0 1 4 4 3.2 3.2 0 0 1-.93 2.25M13 19h-2v-2h2M12 2A10 10 0 0 0 2 12a10 10 0 0 0 10 10 10 10 0 0 0 10-10c0-5.53-4.5-10-10-10Z'/></svg>");
  --md-admonition-icon--warning:
    url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M13 14h-2V9h2m0 9h-2v-2h2M1 21h22L12 2 1 21Z'/></svg>");
  --md-admonition-icon--failure:
    url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M19 6.41 17.59 5 12 10.59 6.41 5 5 6.41 10.59 12 5 17.59 6.41 19 12 13.41 17.59 19 19 17.59 13.41 12 19 6.41Z'/></svg>");
  --md-admonition-icon--danger:
    url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='m11.5 20 4.86-9.73H13V4l-5 9.73h3.5V20M12 2c2.75 0 5.1 1 7.05 2.95C21 6.9 22 9.25 22 12s-1 5.1-2.95 7.05C17.1 21 14.75 22 12 22s-5.1-1-7.05-2.95C3 17.1 2 14.75 2 12s1-5.1 2.95-7.05C6.9 3 9.25 2 12 2Z'/></svg>");
  --md-admonition-icon--bug:
    url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M11 13h2v1h-2v-1m10-8v6c0 5.5-3.8 10.7-9 12-5.2-1.3-9-6.5-9-12V5l9-4 9 4m-4 5h-2.2c-.2-.6-.6-1.1-1.1-1.5l1.2-1.2-.7-.7L12.8 8H12c-.2 0-.5 0-.7.1L9.9 6.6l-.8.8 1.2 1.2c-.5.3-.9.8-1.1 1.4H7v1h2v1H7v1h2v1H7v1h2.2c.4 1.2 1.5 2 2.8 2s2.4-.8 2.8-2H17v-1h-2v-1h2v-1h-2v-1h2v-1m-6 2h2v-1h-2v1Z'/></svg>");
  --md-admonition-icon--example:
    url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M7 2v2h1v14a4 4 0 0 0 4 4 4 4 0 0 0 4-4V4h1V2H7m4 14c-.6 0-1-.4-1-1s.4-1 1-1 1 .4 1 1-.4 1-1 1m2-4c-.6 0-1-.4-1-1s.4-1 1-1 1 .4 1 1-.4 1-1 1m1-5h-4V4h4v3Z'/></svg>");
  --md-admonition-icon--quote:
    url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M14 17h3l2-4V7h-6v6h3M6 17h3l2-4V7H5v6h3l-2 4Z'/></svg>");
}

.md-typeset .admonition,.md-typeset details {
  display: flow-root;
  margin: 1.5625em 0;
  padding: 0 0.6rem;
  color: var(--md-admonition-fg-color);
  font-size: 0.64rem;
  page-break-inside: avoid;
  background-color: var(--md-admonition-bg-color);
  border: 0.05rem solid #448aff;
  border-radius: 0.2rem;
  box-shadow: var(--md-shadow-z1);
}
@media print {
  .md-typeset .admonition,.md-typeset details {
    box-shadow: none;
  }
}
.md-typeset .admonition>*,.md-typeset details>* {
  box-sizing: border-box;
}
.md-typeset .admonition .admonition,.md-typeset details .admonition,.md-typeset .admonition details,.md-typeset details details {
  margin-top: 1em;
  margin-bottom: 1em;
}
.md-typeset .admonition .md-typeset__scrollwrap,.md-typeset details .md-typeset__scrollwrap {
  margin: 1em -0.6rem;
}
.md-typeset .admonition .md-typeset__table,.md-typeset details .md-typeset__table {
  padding: 0 0.6rem;
}
.md-typeset .admonition>.tabbed-set:only-child,.md-typeset details>.tabbed-set:only-child {
  margin-top: 0;
}
html .md-typeset .admonition>:last-child,html .md-typeset details>:last-child {
  margin-bottom: 0.6rem;
}
[dir="ltr"] .md-typeset .admonition-title,[dir="ltr"] .md-typeset summary{
  padding-left: 2rem;
  padding-right: 0.6rem;
}
[dir="rtl"] .md-typeset .admonition-title,[dir="rtl"] .md-typeset summary{
  padding-right: 2rem;
  padding-left: 0.6rem;
}
[dir="ltr"] .md-typeset .admonition-title,[dir="ltr"] .md-typeset summary{
  border-left-width: 0.2rem;
}
[dir="rtl"] .md-typeset .admonition-title,[dir="rtl"] .md-typeset summary{
  border-right-width: 0.2rem;
}
[dir="ltr"] .md-typeset .admonition-title,[dir="ltr"] .md-typeset summary{
  border-top-left-radius: 0.1rem;
}
[dir="rtl"] .md-typeset .admonition-title,[dir="rtl"] .md-typeset summary{
  border-top-right-radius: 0.1rem;
}
[dir="ltr"] .md-typeset .admonition-title,[dir="ltr"] .md-typeset summary{
  border-top-right-radius: 0.1rem;
}
[dir="rtl"] .md-typeset .admonition-title,[dir="rtl"] .md-typeset summary{
  border-top-left-radius: 0.1rem;
}
.md-typeset .admonition-title,.md-typeset summary {
  position: relative;
  margin-top: 0;
  margin-bottom: 0;
  margin-left: -0.6rem;
  margin-right: -0.6rem;
  padding-top: 0.4rem;
  padding-bottom: 0.4rem;
  font-weight: 700;
  background-color: rgba(68, 138, 255, 0.1);
  border: none;
}
html .md-typeset .admonition-title:last-child,html .md-typeset summary:last-child {
  margin-bottom: 0;
}
[dir="ltr"] .md-typeset .admonition-title::before,[dir="ltr"] .md-typeset summary::before{
  left: 0.6rem;
}
[dir="rtl"] .md-typeset .admonition-title::before,[dir="rtl"] .md-typeset summary::before{
  right: 0.6rem;
}
.md-typeset .admonition-title::before,.md-typeset summary::before {
  position: absolute;
  top: 0.625em;
  width: 1rem;
  height: 1rem;
  background-color: #448aff;
  -webkit-mask-image: var(--md-admonition-icon--note);
          mask-image: var(--md-admonition-icon--note);
  -webkit-mask-position: center;
          mask-position: center;
  -webkit-mask-repeat: no-repeat;
          mask-repeat: no-repeat;
  -webkit-mask-size: contain;
          mask-size: contain;
  content: "";
}
.md-typeset .admonition-title code,.md-typeset summary code {
  box-shadow: 0 0 0 0.05rem var(--md-default-fg-color--lightest);
}

.md-typeset .admonition.note,.md-typeset details.note {
  border-color: #448aff;
}

.md-typeset .note>.admonition-title,.md-typeset .note>summary {
  background-color: rgba(68, 138, 255, 0.1);
}
.md-typeset .note>.admonition-title::before,.md-typeset .note>summary::before {
  background-color: #448aff;
  -webkit-mask-image: var(--md-admonition-icon--note);
          mask-image: var(--md-admonition-icon--note);
}
.md-typeset .note>.admonition-title::after,.md-typeset .note>summary::after {
  color: #448aff;
}

.md-typeset .admonition.abstract,.md-typeset details.abstract {
  border-color: #00b0ff;
}

.md-typeset .abstract>.admonition-title,.md-typeset .abstract>summary {
  background-color: rgba(0, 176, 255, 0.1);
}
.md-typeset .abstract>.admonition-title::before,.md-typeset .abstract>summary::before {
  background-color: #00b0ff;
  -webkit-mask-image: var(--md-admonition-icon--abstract);
          mask-image: var(--md-admonition-icon--abstract);
}
.md-typeset .abstract>.admonition-title::after,.md-typeset .abstract>summary::after {
  color: #00b0ff;
}

.md-typeset .admonition.info,.md-typeset details.info {
  border-color: #00b8d4;
}

.md-typeset .info>.admonition-title,.md-typeset .info>summary {
  background-color: rgba(0, 184, 212, 0.1);
}
.md-typeset .info>.admonition-title::before,.md-typeset .info>summary::before {
  background-color: #00b8d4;
  -webkit-mask-image: var(--md-admonition-icon--info);
          mask-image: var(--md-admonition-icon--info);
}
.md-typeset .info>.admonition-title::after,.md-typeset .info>summary::after {
  color: #00b8d4;
}

.md-typeset .admonition.tip,.md-typeset details.tip {
  border-color: #00bfa5;
}

.md-typeset .tip>.admonition-title,.md-typeset .tip>summary {
  background-color: rgba(0, 191, 165, 0.1);
}
.md-typeset .tip>.admonition-title::before,.md-typeset .tip>summary::before {
  background-color: #00bfa5;
  -webkit-mask-image: var(--md-admonition-icon--tip);
          mask-image: var(--md-admonition-icon--tip);
}
.md-typeset .tip>.admonition-title::after,.md-typeset .tip>summary::after {
  color: #00bfa5;
}

.md-typeset .admonition.success,.md-typeset details.success {
  border-color: #00c853;
}

.md-typeset .success>.admonition-title,.md-typeset .success>summary {
  background-color: rgba(0, 200, 83, 0.1);
}
.md-typeset .success>.admonition-title::before,.md-typeset .success>summary::before {
  background-color: #00c853;
  -webkit-mask-image: var(--md-admonition-icon--success);
          mask-image: var(--md-admonition-icon--success);
}
.md-typeset .success>.admonition-title::after,.md-typeset .success>summary::after {
  color: #00c853;
}

.md-typeset .admonition.question,.md-typeset details.question {
  border-color: #64dd17;
}

.md-typeset .question>.admonition-title,.md-typeset .question>summary {
  background-color: rgba(100, 221, 23, 0.1);
}
.md-typeset .question>.admonition-title::before,.md-typeset .question>summary::before {
  background-color: #64dd17;
  -webkit-mask-image: var(--md-admonition-icon--question);
          mask-image: var(--md-admonition-icon--question);
}
.md-typeset .question>.admonition-title::after,.md-typeset .question>summary::after {
  color: #64dd17;
}

.md-typeset .admonition.warning,.md-typeset details.warning {
  border-color: #ff9100;
}

.md-typeset .warning>.admonition-title,.md-typeset .warning>summary {
  background-color: rgba(255, 145, 0, 0.1);
}
.md-typeset .warning>.admonition-title::before,.md-typeset .warning>summary::before {
  background-color: #ff9100;
  -webkit-mask-image: var(--md-admonition-icon--warning);
          mask-image: var(--md-admonition-icon--warning);
}
.md-typeset .warning>.admonition-title::after,.md-typeset .warning>summary::after {
  color: #ff9100;
}

.md-typeset .admonition.failure,.md-typeset details.failure {
  border-color: #ff5252;
}

.md-typeset .failure>.admonition-title,.md-typeset .failure>summary {
  background-color: rgba(255, 82, 82, 0.1);
}
.md-typeset .failure>.admonition-title::before,.md-typeset .failure>summary::before {
  background-color: #ff5252;
  -webkit-mask-image: var(--md-admonition-icon--failure);
          mask-image: var(--md-admonition-icon--failure);
}
.md-typeset .failure>.admonition-title::after,.md-typeset .failure>summary::after {
  color: #ff5252;
}

.md-typeset .admonition.danger,.md-typeset details.danger {
  border-color: #ff1744;
}

.md-typeset .danger>.admonition-title,.md-typeset .danger>summary {
  background-color: rgba(255, 23, 68, 0.1);
}
.md-typeset .danger>.admonition-title::before,.md-typeset .danger>summary::before {
  background-color: #ff1744;
  -webkit-mask-image: var(--md-admonition-icon--danger);
          mask-image: var(--md-admonition-icon--danger);
}
.md-typeset .danger>.admonition-title::after,.md-typeset .danger>summary::after {
  color: #ff1744;
}

.md-typeset .admonition.bug,.md-typeset details.bug {
  border-color: #f50057;
}

.md-typeset .bug>.admonition-title,.md-typeset .bug>summary {
  background-color: rgba(245, 0, 87, 0.1);
}
.md-typeset .bug>.admonition-title::before,.md-typeset .bug>summary::before {
  background-color: #f50057;
  -webkit-mask-image: var(--md-admonition-icon--bug);
          mask-image: var(--md-admonition-icon--bug);
}
.md-typeset .bug>.admonition-title::after,.md-typeset .bug>summary::after {
  color: #f50057;
}

.md-typeset .admonition.example,.md-typeset details.example {
  border-color: #7c4dff;
}

.md-typeset .example>.admonition-title,.md-typeset .example>summary {
  background-color: rgba(124, 77, 255, 0.1);
}
.md-typeset .example>.admonition-title::before,.md-typeset .example>summary::before {
  background-color: #7c4dff;
  -webkit-mask-image: var(--md-admonition-icon--example);
          mask-image: var(--md-admonition-icon--example);
}
.md-typeset .example>.admonition-title::after,.md-typeset .example>summary::after {
  color: #7c4dff;
}

.md-typeset .admonition.quote,.md-typeset details.quote {
  border-color: #9e9e9e;
}

.md-typeset .quote>.admonition-title,.md-typeset .quote>summary {
  background-color: rgba(158, 158, 158, 0.1);
}
.md-typeset .quote>.admonition-title::before,.md-typeset .quote>summary::before {
  background-color: #9e9e9e;
  -webkit-mask-image: var(--md-admonition-icon--quote);
          mask-image: var(--md-admonition-icon--quote);
}
.md-typeset .quote>.admonition-title::after,.md-typeset .quote>summary::after {
  color: #9e9e9e;
}

:root {
  --md-footnotes-icon: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M19 7v4H5.83l3.58-3.59L8 6l-6 6 6 6 1.41-1.42L5.83 13H21V7h-2Z'/></svg>");
}

.md-typeset .footnote {
  color: var(--md-default-fg-color--light);
  font-size: 0.64rem;
}
[dir="ltr"] .md-typeset .footnote>ol{
  margin-left: 0;
}
[dir="rtl"] .md-typeset .footnote>ol{
  margin-right: 0;
}
.md-typeset .footnote>ol>li {
  transition: color 125ms;
}
.md-typeset .footnote>ol>li:target {
  color: var(--md-default-fg-color);
}
.md-typeset .footnote>ol>li:focus-within .footnote-backref {
  transform: translateX(0);
  opacity: 1;
  transition: none;
}
.md-typeset .footnote>ol>li:hover .footnote-backref,.md-typeset .footnote>ol>li:target .footnote-backref {
  transform: translateX(0);
  opacity: 1;
}
.md-typeset .footnote>ol>li>:first-child {
  margin-top: 0;
}
.md-typeset .footnote-ref {
  font-weight: 700;
  font-size: 0.75em;
}
html .md-typeset .footnote-ref {
  outline-offset: 0.1rem;
}
.md-typeset [id^="fnref:"]:target>.footnote-ref {
  outline: auto;
}
.md-typeset .footnote-backref {
  display: inline-block;
  color: var(--md-typeset-a-color);
  font-size: 0;
  vertical-align: text-bottom;
  transform: translateX(0.25rem);
  opacity: 0;
  transition: color 250ms, transform 250ms 250ms, opacity 125ms 250ms;
}
@media print {
  .md-typeset .footnote-backref {
    color: var(--md-typeset-a-color);
    transform: translateX(0);
    opacity: 1;
  }
}
[dir=rtl] .md-typeset .footnote-backref {
  transform: translateX(-0.25rem);
}
.md-typeset .footnote-backref:hover {
  color: var(--md-accent-fg-color);
}
.md-typeset .footnote-backref::before {
  display: inline-block;
  width: 0.8rem;
  height: 0.8rem;
  background-color: currentcolor;
  -webkit-mask-image: var(--md-footnotes-icon);
          mask-image: var(--md-footnotes-icon);
  -webkit-mask-position: center;
          mask-position: center;
  -webkit-mask-repeat: no-repeat;
          mask-repeat: no-repeat;
  -webkit-mask-size: contain;
          mask-size: contain;
  content: "";
}
[dir=rtl] .md-typeset .footnote-backref::before svg {
  transform: scaleX(-1);
}

[dir="ltr"] .md-typeset .headerlink{
  margin-left: 0.5rem;
}

[dir="rtl"] .md-typeset .headerlink{
  margin-right: 0.5rem;
}

.md-typeset .headerlink {
  display: inline-block;
  color: var(--md-default-fg-color--lighter);
  opacity: 0;
  transition: color 250ms, opacity 125ms;
}
@media print {
  .md-typeset .headerlink {
    display: none;
  }
}
.md-typeset :hover>.headerlink,.md-typeset :target>.headerlink,.md-typeset .headerlink:focus {
  opacity: 1;
  transition: color 250ms, opacity 125ms;
}
.md-typeset :target>.headerlink,.md-typeset .headerlink:focus,.md-typeset .headerlink:hover {
  color: var(--md-accent-fg-color);
}
.md-typeset :target {
  --md-scroll-margin: 3.6rem;
  --md-scroll-offset: 0rem;
  scroll-margin-top: calc(var(--md-scroll-margin) - var(--md-scroll-offset));
}
@media screen and (min-width: 76.25em) {
  .md-header--lifted~.md-container .md-typeset :target {
    --md-scroll-margin: 6rem;
  }
}
.md-typeset h1:target,.md-typeset h2:target,.md-typeset h3:target {
  --md-scroll-offset: 0.2rem;
}
.md-typeset h4:target {
  --md-scroll-offset: 0.15rem;
}

.md-typeset div.arithmatex {
  overflow: auto;
}
@media screen and (max-width: 44.9375em) {
  .md-typeset div.arithmatex {
    margin: 0 -0.8rem;
  }
}
.md-typeset div.arithmatex>* {
  width: -webkit-min-content;
  width: -moz-min-content;
  width: min-content;
  margin-left: auto !important;
  margin-right: auto !important;
  padding: 0 0.8rem;
  touch-action: auto;
}
.md-typeset div.arithmatex>* mjx-container {
  margin: 0 !important;
}

.md-typeset del.critic {
  background-color: var(--md-typeset-del-color);
  -webkit-box-decoration-break: clone;
          box-decoration-break: clone;
}
.md-typeset ins.critic {
  background-color: var(--md-typeset-ins-color);
  -webkit-box-decoration-break: clone;
          box-decoration-break: clone;
}
.md-typeset .critic.comment {
  color: var(--md-code-hl-comment-color);
  -webkit-box-decoration-break: clone;
          box-decoration-break: clone;
}
.md-typeset .critic.comment::before {
  content: "/* ";
}
.md-typeset .critic.comment::after {
  content: " */";
}
.md-typeset .critic.block {
  display: block;
  margin: 1em 0;
  padding-left: 0.8rem;
  padding-right: 0.8rem;
  overflow: auto;
  box-shadow: none;
}
.md-typeset .critic.block>:first-child {
  margin-top: 0.5em;
}
.md-typeset .critic.block>:last-child {
  margin-bottom: 0.5em;
}

:root {
  --md-details-icon: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M8.59 16.58 13.17 12 8.59 7.41 10 6l6 6-6 6-1.41-1.42Z'/></svg>");
}

.md-typeset details {
  display: flow-root;
  padding-top: 0;
  overflow: visible;
}
.md-typeset details[open]>summary::after {
  transform: rotate(90deg);
}
.md-typeset details:not([open]) {
  padding-bottom: 0;
  box-shadow: none;
}
.md-typeset details:not([open])>summary {
  border-radius: 0.1rem;
}
[dir="ltr"] .md-typeset summary{
  padding-right: 1.8rem;
}
[dir="rtl"] .md-typeset summary{
  padding-left: 1.8rem;
}
[dir="ltr"] .md-typeset summary{
  border-top-left-radius: 0.1rem;
}
[dir="rtl"] .md-typeset summary{
  border-top-right-radius: 0.1rem;
}
[dir="ltr"] .md-typeset summary{
  border-top-right-radius: 0.1rem;
}
[dir="rtl"] .md-typeset summary{
  border-top-left-radius: 0.1rem;
}
.md-typeset summary {
  display: block;
  min-height: 1rem;
  cursor: pointer;
}
.md-typeset summary.focus-visible {
  outline-color: var(--md-accent-fg-color);
  outline-offset: 0.2rem;
}
.md-typeset summary:not(.focus-visible) {
  outline: none;
  -webkit-tap-highlight-color: transparent;
}
[dir="ltr"] .md-typeset summary::after{
  right: 0.4rem;
}
[dir="rtl"] .md-typeset summary::after{
  left: 0.4rem;
}
.md-typeset summary::after {
  position: absolute;
  top: 0.625em;
  width: 1rem;
  height: 1rem;
  background-color: currentcolor;
  -webkit-mask-image: var(--md-details-icon);
          mask-image: var(--md-details-icon);
  -webkit-mask-position: center;
          mask-position: center;
  -webkit-mask-repeat: no-repeat;
          mask-repeat: no-repeat;
  -webkit-mask-size: contain;
          mask-size: contain;
  transform: rotate(0deg);
  transition: transform 250ms;
  content: "";
}
[dir=rtl] .md-typeset summary::after {
  transform: rotate(180deg);
}
.md-typeset summary::marker {
  display: none;
}
.md-typeset summary::-webkit-details-marker {
  display: none;
}

.md-typeset .emojione,.md-typeset .twemoji,.md-typeset .gemoji {
  display: inline-flex;
  height: 1.125em;
  vertical-align: text-top;
}
.md-typeset .emojione svg,.md-typeset .twemoji svg,.md-typeset .gemoji svg {
  width: 1.125em;
  max-height: 100%;
  fill: currentcolor;
}

.highlight .o,.highlight .ow {
  color: var(--md-code-hl-operator-color);
}
.highlight .p {
  color: var(--md-code-hl-punctuation-color);
}
.highlight .cpf,.highlight .l,.highlight .s,.highlight .sb,.highlight .sc,.highlight .s2,.highlight .si,.highlight .s1,.highlight .ss {
  color: var(--md-code-hl-string-color);
}
.highlight .cp,.highlight .se,.highlight .sh,.highlight .sr,.highlight .sx {
  color: var(--md-code-hl-special-color);
}
.highlight .m,.highlight .mb,.highlight .mf,.highlight .mh,.highlight .mi,.highlight .il,.highlight .mo {
  color: var(--md-code-hl-number-color);
}
.highlight .k,.highlight .kd,.highlight .kn,.highlight .kp,.highlight .kr,.highlight .kt {
  color: var(--md-code-hl-keyword-color);
}
.highlight .kc,.highlight .n {
  color: var(--md-code-hl-name-color);
}
.highlight .no,.highlight .nb,.highlight .bp {
  color: var(--md-code-hl-constant-color);
}
.highlight .nc,.highlight .ne,.highlight .nf,.highlight .nn {
  color: var(--md-code-hl-function-color);
}
.highlight .nd,.highlight .ni,.highlight .nl,.highlight .nt {
  color: var(--md-code-hl-keyword-color);
}
.highlight .c,.highlight .cm,.highlight .c1,.highlight .ch,.highlight .cs,.highlight .sd {
  color: var(--md-code-hl-comment-color);
}
.highlight .na,.highlight .nv,.highlight .vc,.highlight .vg,.highlight .vi {
  color: var(--md-code-hl-variable-color);
}
.highlight .ge,.highlight .gr,.highlight .gh,.highlight .go,.highlight .gp,.highlight .gs,.highlight .gu,.highlight .gt {
  color: var(--md-code-hl-generic-color);
}
.highlight .gd,.highlight .gi {
  margin: 0 -0.125em;
  padding: 0 0.125em;
  border-radius: 0.1rem;
}
.highlight .gd {
  background-color: var(--md-typeset-del-color);
}
.highlight .gi {
  background-color: var(--md-typeset-ins-color);
}
.highlight .hll {
  display: block;
  margin: 0 -1.1764705882em;
  padding: 0 1.1764705882em;
  background-color: var(--md-code-hl-color);
}
.highlight span.filename {
  position: relative;
  display: flow-root;
  margin-top: 1em;
  padding: 0.6617647059em 1.1764705882em;
  font-weight: 700;
  font-size: 0.85em;
  background-color: var(--md-code-bg-color);
  border-bottom: 0.05rem solid var(--md-default-fg-color--lightest);
  border-top-left-radius: 0.1rem;
  border-top-right-radius: 0.1rem;
}
.highlight span.filename+pre {
  margin-top: 0;
}
.highlight span.filename+pre>code {
  border-top-left-radius: 0;
  border-top-right-radius: 0;
}
.highlight [data-linenos]::before {
  position: -webkit-sticky;
  position: sticky;
  left: -1.1764705882em;
  z-index: 3;
  float: left;
  margin-right: 1.1764705882em;
  margin-left: -1.1764705882em;
  padding-left: 1.1764705882em;
  color: var(--md-default-fg-color--light);
  background-color: var(--md-code-bg-color);
  box-shadow: -0.05rem 0 var(--md-default-fg-color--lightest) inset;
  content: attr(data-linenos);
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}
.highlight code a[id] {
  position: absolute;
  visibility: hidden;
}
.highlight code[data-md-copying] .hll {
  display: contents;
}
.highlight code[data-md-copying] .md-annotation {
  display: none;
}

.highlighttable {
  display: flow-root;
}
.highlighttable tbody,.highlighttable td {
  display: block;
  padding: 0;
}
.highlighttable tr {
  display: flex;
}
.highlighttable pre {
  margin: 0;
}
.highlighttable th.filename {
  flex-grow: 1;
  padding: 0;
  text-align: left;
}
.highlighttable th.filename span.filename {
  margin-top: 0;
}
.highlighttable .linenos {
  padding: 0.7720588235em 1.1764705882em;
  padding-right: 0;
  font-size: 0.85em;
  background-color: var(--md-code-bg-color);
  border-top-left-radius: 0.1rem;
  border-bottom-left-radius: 0.1rem;
  -webkit-user-select: none;
     -moz-user-select: none;
          user-select: none;
}
.highlighttable .linenodiv {
  padding-right: 0.5882352941em;
  box-shadow: -0.05rem 0 var(--md-default-fg-color--lightest) inset;
}
.highlighttable .linenodiv pre {
  color: var(--md-default-fg-color--light);
  text-align: right;
}
.highlighttable .code {
  flex: 1;
  min-width: 0;
}

.linenodiv a {
  color: inherit;
}

.md-typeset .highlighttable {
  margin: 1em 0;
  direction: ltr;
}
.md-typeset .highlighttable>tbody>tr>.code>div>pre>code {
  border-top-left-radius: 0;
  border-bottom-left-radius: 0;
}
.md-typeset .highlight+.result {
  margin-top: calc(-1em + -0.125em);
  padding: 0 1em;
  overflow: visible;
  border: 0.05rem solid var(--md-code-bg-color);
  border-top-width: 0.1rem;
  border-bottom-right-radius: 0.1rem;
  border-bottom-left-radius: 0.1rem;
}
.md-typeset .highlight+.result::after {
  display: block;
  clear: both;
  content: "";
}

@media screen and (max-width: 44.9375em) {
  .md-content__inner>.highlight {
    margin: 1em -0.8rem;
  }
  .md-content__inner>.highlight>.filename,.md-content__inner>.highlight>pre>code {
    border-radius: 0;
  }
  .md-content__inner>.highlight>.highlighttable>tbody>tr>.filename span.filename,.md-content__inner>.highlight>.highlighttable>tbody>tr>.linenos,.md-content__inner>.highlight>.highlighttable>tbody>tr>.code>div>pre>code {
    border-radius: 0;
  }
  .md-content__inner>.highlight+.result {
    margin-left: -0.8rem;
    margin-right: -0.8rem;
    border-left-width: 0;
    border-right-width: 0;
    border-radius: 0;
  }
}
.md-typeset .keys kbd::before,.md-typeset .keys kbd::after {
  position: relative;
  margin: 0;
  color: inherit;
  -moz-osx-font-smoothing: initial;
  -webkit-font-smoothing: initial;
}
.md-typeset .keys span {
  padding: 0 0.2em;
  color: var(--md-default-fg-color--light);
}
.md-typeset .keys .key-alt::before {
  padding-right: 0.4em;
  content: "⎇";
}
.md-typeset .keys .key-left-alt::before {
  padding-right: 0.4em;
  content: "⎇";
}
.md-typeset .keys .key-right-alt::before {
  padding-right: 0.4em;
  content: "⎇";
}
.md-typeset .keys .key-command::before {
  padding-right: 0.4em;
  content: "⌘";
}
.md-typeset .keys .key-left-command::before {
  padding-right: 0.4em;
  content: "⌘";
}
.md-typeset .keys .key-right-command::before {
  padding-right: 0.4em;
  content: "⌘";
}
.md-typeset .keys .key-control::before {
  padding-right: 0.4em;
  content: "⌃";
}
.md-typeset .keys .key-left-control::before {
  padding-right: 0.4em;
  content: "⌃";
}
.md-typeset .keys .key-right-control::before {
  padding-right: 0.4em;
  content: "⌃";
}
.md-typeset .keys .key-meta::before {
  padding-right: 0.4em;
  content: "◆";
}
.md-typeset .keys .key-left-meta::before {
  padding-right: 0.4em;
  content: "◆";
}
.md-typeset .keys .key-right-meta::before {
  padding-right: 0.4em;
  content: "◆";
}
.md-typeset .keys .key-option::before {
  padding-right: 0.4em;
  content: "⌥";
}
.md-typeset .keys .key-left-option::before {
  padding-right: 0.4em;
  content: "⌥";
}
.md-typeset .keys .key-right-option::before {
  padding-right: 0.4em;
  content: "⌥";
}
.md-typeset .keys .key-shift::before {
  padding-right: 0.4em;
  content: "⇧";
}
.md-typeset .keys .key-left-shift::before {
  padding-right: 0.4em;
  content: "⇧";
}
.md-typeset .keys .key-right-shift::before {
  padding-right: 0.4em;
  content: "⇧";
}
.md-typeset .keys .key-super::before {
  padding-right: 0.4em;
  content: "❖";
}
.md-typeset .keys .key-left-super::before {
  padding-right: 0.4em;
  content: "❖";
}
.md-typeset .keys .key-right-super::before {
  padding-right: 0.4em;
  content: "❖";
}
.md-typeset .keys .key-windows::before {
  padding-right: 0.4em;
  content: "⊞";
}
.md-typeset .keys .key-left-windows::before {
  padding-right: 0.4em;
  content: "⊞";
}
.md-typeset .keys .key-right-windows::before {
  padding-right: 0.4em;
  content: "⊞";
}
.md-typeset .keys .key-arrow-down::before {
  padding-right: 0.4em;
  content: "↓";
}
.md-typeset .keys .key-arrow-left::before {
  padding-right: 0.4em;
  content: "←";
}
.md-typeset .keys .key-arrow-right::before {
  padding-right: 0.4em;
  content: "→";
}
.md-typeset .keys .key-arrow-up::before {
  padding-right: 0.4em;
  content: "↑";
}
.md-typeset .keys .key-backspace::before {
  padding-right: 0.4em;
  content: "⌫";
}
.md-typeset .keys .key-backtab::before {
  padding-right: 0.4em;
  content: "⇤";
}
.md-typeset .keys .key-caps-lock::before {
  padding-right: 0.4em;
  content: "⇪";
}
.md-typeset .keys .key-clear::before {
  padding-right: 0.4em;
  content: "⌧";
}
.md-typeset .keys .key-context-menu::before {
  padding-right: 0.4em;
  content: "☰";
}
.md-typeset .keys .key-delete::before {
  padding-right: 0.4em;
  content: "⌦";
}
.md-typeset .keys .key-eject::before {
  padding-right: 0.4em;
  content: "⏏";
}
.md-typeset .keys .key-end::before {
  padding-right: 0.4em;
  content: "⤓";
}
.md-typeset .keys .key-escape::before {
  padding-right: 0.4em;
  content: "⎋";
}
.md-typeset .keys .key-home::before {
  padding-right: 0.4em;
  content: "⤒";
}
.md-typeset .keys .key-insert::before {
  padding-right: 0.4em;
  content: "⎀";
}
.md-typeset .keys .key-page-down::before {
  padding-right: 0.4em;
  content: "⇟";
}
.md-typeset .keys .key-page-up::before {
  padding-right: 0.4em;
  content: "⇞";
}
.md-typeset .keys .key-print-screen::before {
  padding-right: 0.4em;
  content: "⎙";
}
.md-typeset .keys .key-tab::after {
  padding-left: 0.4em;
  content: "⇥";
}
.md-typeset .keys .key-num-enter::after {
  padding-left: 0.4em;
  content: "⌤";
}
.md-typeset .keys .key-enter::after {
  padding-left: 0.4em;
  content: "⏎";
}

:root {
  --md-tabbed-icon--prev: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M15.41 16.58 10.83 12l4.58-4.59L14 6l-6 6 6 6 1.41-1.42Z'/></svg>");
  --md-tabbed-icon--next: url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M8.59 16.58 13.17 12 8.59 7.41 10 6l6 6-6 6-1.41-1.42Z'/></svg>");
}

.md-typeset .tabbed-set {
  position: relative;
  display: flex;
  flex-flow: column wrap;
  margin: 1em 0;
  border-radius: 0.1rem;
}
.md-typeset .tabbed-set>input {
  position: absolute;
  width: 0;
  height: 0;
  opacity: 0;
}
.md-typeset .tabbed-set>input:target {
  --md-scroll-offset: 0.625em;
}
.md-typeset .tabbed-labels {
  display: flex;
  max-width: 100%;
  overflow: auto;
  box-shadow: 0 -0.05rem var(--md-default-fg-color--lightest) inset;
  -ms-overflow-style: none;
  scrollbar-width: none;
}
@media print {
  .md-typeset .tabbed-labels {
    display: contents;
  }
}
@media screen {
  .js .md-typeset .tabbed-labels {
    position: relative;
  }
  .js .md-typeset .tabbed-labels::before {
    position: absolute;
    bottom: 0;
    left: 0;
    display: block;
    width: var(--md-indicator-width);
    height: 2px;
    background: var(--md-accent-fg-color);
    transform: translateX(var(--md-indicator-x));
    transition: width 225ms, transform 250ms;
    transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1);
    content: "";
  }
}
.md-typeset .tabbed-labels::-webkit-scrollbar {
  display: none;
}
.md-typeset .tabbed-labels>label {
  flex-shrink: 0;
  width: auto;
  padding: 0.78125em 1.25em 0.625em;
  color: var(--md-default-fg-color--light);
  font-weight: 700;
  font-size: 0.64rem;
  white-space: nowrap;
  border-bottom: 0.1rem solid transparent;
  border-radius: 0.1rem 0.1rem 0 0;
  cursor: pointer;
  transition: background-color 250ms, color 250ms;
  scroll-margin-inline-start: 1rem;
}
@media print {
  .md-typeset .tabbed-labels>label:nth-child(1) {
    order: 1;
  }
  .md-typeset .tabbed-labels>label:nth-child(2) {
    order: 2;
  }
  .md-typeset .tabbed-labels>label:nth-child(3) {
    order: 3;
  }
  .md-typeset .tabbed-labels>label:nth-child(4) {
    order: 4;
  }
  .md-typeset .tabbed-labels>label:nth-child(5) {
    order: 5;
  }
  .md-typeset .tabbed-labels>label:nth-child(6) {
    order: 6;
  }
  .md-typeset .tabbed-labels>label:nth-child(7) {
    order: 7;
  }
  .md-typeset .tabbed-labels>label:nth-child(8) {
    order: 8;
  }
  .md-typeset .tabbed-labels>label:nth-child(9) {
    order: 9;
  }
  .md-typeset .tabbed-labels>label:nth-child(10) {
    order: 10;
  }
  .md-typeset .tabbed-labels>label:nth-child(11) {
    order: 11;
  }
  .md-typeset .tabbed-labels>label:nth-child(12) {
    order: 12;
  }
  .md-typeset .tabbed-labels>label:nth-child(13) {
    order: 13;
  }
  .md-typeset .tabbed-labels>label:nth-child(14) {
    order: 14;
  }
  .md-typeset .tabbed-labels>label:nth-child(15) {
    order: 15;
  }
  .md-typeset .tabbed-labels>label:nth-child(16) {
    order: 16;
  }
  .md-typeset .tabbed-labels>label:nth-child(17) {
    order: 17;
  }
  .md-typeset .tabbed-labels>label:nth-child(18) {
    order: 18;
  }
  .md-typeset .tabbed-labels>label:nth-child(19) {
    order: 19;
  }
  .md-typeset .tabbed-labels>label:nth-child(20) {
    order: 20;
  }
}
.md-typeset .tabbed-labels>label:hover {
  color: var(--md-accent-fg-color);
}
.md-typeset .tabbed-content {
  width: 100%;
}
@media print {
  .md-typeset .tabbed-content {
    display: contents;
  }
}
.md-typeset .tabbed-block {
  display: none;
}
@media print {
  .md-typeset .tabbed-block {
    display: block;
  }
  .md-typeset .tabbed-block:nth-child(1) {
    order: 1;
  }
  .md-typeset .tabbed-block:nth-child(2) {
    order: 2;
  }
  .md-typeset .tabbed-block:nth-child(3) {
    order: 3;
  }
  .md-typeset .tabbed-block:nth-child(4) {
    order: 4;
  }
  .md-typeset .tabbed-block:nth-child(5) {
    order: 5;
  }
  .md-typeset .tabbed-block:nth-child(6) {
    order: 6;
  }
  .md-typeset .tabbed-block:nth-child(7) {
    order: 7;
  }
  .md-typeset .tabbed-block:nth-child(8) {
    order: 8;
  }
  .md-typeset .tabbed-block:nth-child(9) {
    order: 9;
  }
  .md-typeset .tabbed-block:nth-child(10) {
    order: 10;
  }
  .md-typeset .tabbed-block:nth-child(11) {
    order: 11;
  }
  .md-typeset .tabbed-block:nth-child(12) {
    order: 12;
  }
  .md-typeset .tabbed-block:nth-child(13) {
    order: 13;
  }
  .md-typeset .tabbed-block:nth-child(14) {
    order: 14;
  }
  .md-typeset .tabbed-block:nth-child(15) {
    order: 15;
  }
  .md-typeset .tabbed-block:nth-child(16) {
    order: 16;
  }
  .md-typeset .tabbed-block:nth-child(17) {
    order: 17;
  }
  .md-typeset .tabbed-block:nth-child(18) {
    order: 18;
  }
  .md-typeset .tabbed-block:nth-child(19) {
    order: 19;
  }
  .md-typeset .tabbed-block:nth-child(20) {
    order: 20;
  }
}
.md-typeset .tabbed-block>pre:first-child,.md-typeset .tabbed-block>.highlight:first-child>pre {
  margin: 0;
}
.md-typeset .tabbed-block>pre:first-child>code,.md-typeset .tabbed-block>.highlight:first-child>pre>code {
  border-top-left-radius: 0;
  border-top-right-radius: 0;
}
.md-typeset .tabbed-block>.highlight:first-child>.filename {
  margin: 0;
  border-top-left-radius: 0;
  border-top-right-radius: 0;
}
.md-typeset .tabbed-block>.highlight:first-child>.highlighttable {
  margin: 0;
}
.md-typeset .tabbed-block>.highlight:first-child>.highlighttable>tbody>tr>.filename span.filename,.md-typeset .tabbed-block>.highlight:first-child>.highlighttable>tbody>tr>.linenos {
  margin: 0;
  border-top-left-radius: 0;
  border-top-right-radius: 0;
}
.md-typeset .tabbed-block>.highlight:first-child>.highlighttable>tbody>tr>.code>div>pre>code {
  border-top-left-radius: 0;
  border-top-right-radius: 0;
}
.md-typeset .tabbed-block>.highlight:first-child+.result {
  margin-top: -0.125em;
}
.md-typeset .tabbed-block>.tabbed-set {
  margin: 0;
}
.md-typeset .tabbed-button {
  display: block;
  align-self: center;
  width: 0.9rem;
  height: 0.9rem;
  margin-top: 0.1rem;
  color: var(--md-default-fg-color--light);
  border-radius: 100%;
  cursor: pointer;
  transition: background-color 250ms;
  pointer-events: initial;
}
.md-typeset .tabbed-button:hover {
  color: var(--md-accent-fg-color);
  background-color: var(--md-accent-fg-color--transparent);
}
.md-typeset .tabbed-button::after {
  display: block;
  width: 100%;
  height: 100%;
  background-color: currentcolor;
  transition: background-color 250ms, transform 250ms;
  -webkit-mask-image: var(--md-tabbed-icon--prev);
          mask-image: var(--md-tabbed-icon--prev);
  -webkit-mask-position: center;
          mask-position: center;
  -webkit-mask-repeat: no-repeat;
          mask-repeat: no-repeat;
  -webkit-mask-size: contain;
          mask-size: contain;
  content: "";
}
.md-typeset .tabbed-control {
  position: absolute;
  display: flex;
  justify-content: start;
  width: 1.2rem;
  height: 1.9rem;
  background: linear-gradient(to right, var(--md-default-bg-color) 60%, transparent);
  transition: opacity 125ms;
  pointer-events: none;
}
[dir=rtl] .md-typeset .tabbed-control {
  transform: rotate(180deg);
}
.md-typeset .tabbed-control[hidden] {
  opacity: 0;
}
.md-typeset .tabbed-control--next {
  right: 0;
  justify-content: end;
  background: linear-gradient(to left, var(--md-default-bg-color) 60%, transparent);
}
.md-typeset .tabbed-control--next .tabbed-button::after {
  -webkit-mask-image: var(--md-tabbed-icon--next);
          mask-image: var(--md-tabbed-icon--next);
}

@media screen and (max-width: 44.9375em) {
  [dir="ltr"] .md-content__inner>.tabbed-set .tabbed-labels{
    padding-left: 0.8rem;
  }
  [dir="rtl"] .md-content__inner>.tabbed-set .tabbed-labels{
    padding-right: 0.8rem;
  }
  .md-content__inner>.tabbed-set .tabbed-labels {
    max-width: 100vw;
    margin: 0 -0.8rem;
    scroll-padding-inline-start: 0.8rem;
  }
  [dir="ltr"] .md-content__inner>.tabbed-set .tabbed-labels::after{
    padding-right: 0.8rem;
  }
  [dir="rtl"] .md-content__inner>.tabbed-set .tabbed-labels::after{
    padding-left: 0.8rem;
  }
  .md-content__inner>.tabbed-set .tabbed-labels::after {
    content: "";
  }
  [dir="ltr"] .md-content__inner>.tabbed-set .tabbed-labels~.tabbed-control--prev{
    margin-left: -0.8rem;
  }
  [dir="rtl"] .md-content__inner>.tabbed-set .tabbed-labels~.tabbed-control--prev{
    margin-right: -0.8rem;
  }
  [dir="ltr"] .md-content__inner>.tabbed-set .tabbed-labels~.tabbed-control--prev{
    padding-left: 0.8rem;
  }
  [dir="rtl"] .md-content__inner>.tabbed-set .tabbed-labels~.tabbed-control--prev{
    padding-right: 0.8rem;
  }
  .md-content__inner>.tabbed-set .tabbed-labels~.tabbed-control--prev {
    width: 2rem;
  }
  [dir="ltr"] .md-content__inner>.tabbed-set .tabbed-labels~.tabbed-control--next{
    margin-right: -0.8rem;
  }
  [dir="rtl"] .md-content__inner>.tabbed-set .tabbed-labels~.tabbed-control--next{
    margin-left: -0.8rem;
  }
  [dir="ltr"] .md-content__inner>.tabbed-set .tabbed-labels~.tabbed-control--next{
    padding-right: 0.8rem;
  }
  [dir="rtl"] .md-content__inner>.tabbed-set .tabbed-labels~.tabbed-control--next{
    padding-left: 0.8rem;
  }
  .md-content__inner>.tabbed-set .tabbed-labels~.tabbed-control--next {
    width: 2rem;
  }
}
@media screen {
  .md-typeset .tabbed-set>input:nth-child(20):checked~.tabbed-labels>:nth-child(20),.md-typeset .tabbed-set>input:nth-child(19):checked~.tabbed-labels>:nth-child(19),.md-typeset .tabbed-set>input:nth-child(18):checked~.tabbed-labels>:nth-child(18),.md-typeset .tabbed-set>input:nth-child(17):checked~.tabbed-labels>:nth-child(17),.md-typeset .tabbed-set>input:nth-child(16):checked~.tabbed-labels>:nth-child(16),.md-typeset .tabbed-set>input:nth-child(15):checked~.tabbed-labels>:nth-child(15),.md-typeset .tabbed-set>input:nth-child(14):checked~.tabbed-labels>:nth-child(14),.md-typeset .tabbed-set>input:nth-child(13):checked~.tabbed-labels>:nth-child(13),.md-typeset .tabbed-set>input:nth-child(12):checked~.tabbed-labels>:nth-child(12),.md-typeset .tabbed-set>input:nth-child(11):checked~.tabbed-labels>:nth-child(11),.md-typeset .tabbed-set>input:nth-child(10):checked~.tabbed-labels>:nth-child(10),.md-typeset .tabbed-set>input:nth-child(9):checked~.tabbed-labels>:nth-child(9),.md-typeset .tabbed-set>input:nth-child(8):checked~.tabbed-labels>:nth-child(8),.md-typeset .tabbed-set>input:nth-child(7):checked~.tabbed-labels>:nth-child(7),.md-typeset .tabbed-set>input:nth-child(6):checked~.tabbed-labels>:nth-child(6),.md-typeset .tabbed-set>input:nth-child(5):checked~.tabbed-labels>:nth-child(5),.md-typeset .tabbed-set>input:nth-child(4):checked~.tabbed-labels>:nth-child(4),.md-typeset .tabbed-set>input:nth-child(3):checked~.tabbed-labels>:nth-child(3),.md-typeset .tabbed-set>input:nth-child(2):checked~.tabbed-labels>:nth-child(2),.md-typeset .tabbed-set>input:nth-child(1):checked~.tabbed-labels>:nth-child(1) {
    color: var(--md-accent-fg-color);
  }
  .no-js .md-typeset .tabbed-set>input:nth-child(20):checked~.tabbed-labels>:nth-child(20),.md-typeset .no-js .tabbed-set>input:nth-child(20):checked~.tabbed-labels>:nth-child(20),.no-js .md-typeset .tabbed-set>input:nth-child(19):checked~.tabbed-labels>:nth-child(19),.md-typeset .no-js .tabbed-set>input:nth-child(19):checked~.tabbed-labels>:nth-child(19),.no-js .md-typeset .tabbed-set>input:nth-child(18):checked~.tabbed-labels>:nth-child(18),.md-typeset .no-js .tabbed-set>input:nth-child(18):checked~.tabbed-labels>:nth-child(18),.no-js .md-typeset .tabbed-set>input:nth-child(17):checked~.tabbed-labels>:nth-child(17),.md-typeset .no-js .tabbed-set>input:nth-child(17):checked~.tabbed-labels>:nth-child(17),.no-js .md-typeset .tabbed-set>input:nth-child(16):checked~.tabbed-labels>:nth-child(16),.md-typeset .no-js .tabbed-set>input:nth-child(16):checked~.tabbed-labels>:nth-child(16),.no-js .md-typeset .tabbed-set>input:nth-child(15):checked~.tabbed-labels>:nth-child(15),.md-typeset .no-js .tabbed-set>input:nth-child(15):checked~.tabbed-labels>:nth-child(15),.no-js .md-typeset .tabbed-set>input:nth-child(14):checked~.tabbed-labels>:nth-child(14),.md-typeset .no-js .tabbed-set>input:nth-child(14):checked~.tabbed-labels>:nth-child(14),.no-js .md-typeset .tabbed-set>input:nth-child(13):checked~.tabbed-labels>:nth-child(13),.md-typeset .no-js .tabbed-set>input:nth-child(13):checked~.tabbed-labels>:nth-child(13),.no-js .md-typeset .tabbed-set>input:nth-child(12):checked~.tabbed-labels>:nth-child(12),.md-typeset .no-js .tabbed-set>input:nth-child(12):checked~.tabbed-labels>:nth-child(12),.no-js .md-typeset .tabbed-set>input:nth-child(11):checked~.tabbed-labels>:nth-child(11),.md-typeset .no-js .tabbed-set>input:nth-child(11):checked~.tabbed-labels>:nth-child(11),.no-js .md-typeset .tabbed-set>input:nth-child(10):checked~.tabbed-labels>:nth-child(10),.md-typeset .no-js .tabbed-set>input:nth-child(10):checked~.tabbed-labels>:nth-child(10),.no-js .md-typeset .tabbed-set>input:nth-child(9):checked~.tabbed-labels>:nth-child(9),.md-typeset .no-js .tabbed-set>input:nth-child(9):checked~.tabbed-labels>:nth-child(9),.no-js .md-typeset .tabbed-set>input:nth-child(8):checked~.tabbed-labels>:nth-child(8),.md-typeset .no-js .tabbed-set>input:nth-child(8):checked~.tabbed-labels>:nth-child(8),.no-js .md-typeset .tabbed-set>input:nth-child(7):checked~.tabbed-labels>:nth-child(7),.md-typeset .no-js .tabbed-set>input:nth-child(7):checked~.tabbed-labels>:nth-child(7),.no-js .md-typeset .tabbed-set>input:nth-child(6):checked~.tabbed-labels>:nth-child(6),.md-typeset .no-js .tabbed-set>input:nth-child(6):checked~.tabbed-labels>:nth-child(6),.no-js .md-typeset .tabbed-set>input:nth-child(5):checked~.tabbed-labels>:nth-child(5),.md-typeset .no-js .tabbed-set>input:nth-child(5):checked~.tabbed-labels>:nth-child(5),.no-js .md-typeset .tabbed-set>input:nth-child(4):checked~.tabbed-labels>:nth-child(4),.md-typeset .no-js .tabbed-set>input:nth-child(4):checked~.tabbed-labels>:nth-child(4),.no-js .md-typeset .tabbed-set>input:nth-child(3):checked~.tabbed-labels>:nth-child(3),.md-typeset .no-js .tabbed-set>input:nth-child(3):checked~.tabbed-labels>:nth-child(3),.no-js .md-typeset .tabbed-set>input:nth-child(2):checked~.tabbed-labels>:nth-child(2),.md-typeset .no-js .tabbed-set>input:nth-child(2):checked~.tabbed-labels>:nth-child(2),.no-js .md-typeset .tabbed-set>input:nth-child(1):checked~.tabbed-labels>:nth-child(1),.md-typeset .no-js .tabbed-set>input:nth-child(1):checked~.tabbed-labels>:nth-child(1) {
    border-color: var(--md-accent-fg-color);
  }
}

.md-typeset .tabbed-set>input:nth-child(20).focus-visible~.tabbed-labels>:nth-child(20),.md-typeset .tabbed-set>input:nth-child(19).focus-visible~.tabbed-labels>:nth-child(19),.md-typeset .tabbed-set>input:nth-child(18).focus-visible~.tabbed-labels>:nth-child(18),.md-typeset .tabbed-set>input:nth-child(17).focus-visible~.tabbed-labels>:nth-child(17),.md-typeset .tabbed-set>input:nth-child(16).focus-visible~.tabbed-labels>:nth-child(16),.md-typeset .tabbed-set>input:nth-child(15).focus-visible~.tabbed-labels>:nth-child(15),.md-typeset .tabbed-set>input:nth-child(14).focus-visible~.tabbed-labels>:nth-child(14),.md-typeset .tabbed-set>input:nth-child(13).focus-visible~.tabbed-labels>:nth-child(13),.md-typeset .tabbed-set>input:nth-child(12).focus-visible~.tabbed-labels>:nth-child(12),.md-typeset .tabbed-set>input:nth-child(11).focus-visible~.tabbed-labels>:nth-child(11),.md-typeset .tabbed-set>input:nth-child(10).focus-visible~.tabbed-labels>:nth-child(10),.md-typeset .tabbed-set>input:nth-child(9).focus-visible~.tabbed-labels>:nth-child(9),.md-typeset .tabbed-set>input:nth-child(8).focus-visible~.tabbed-labels>:nth-child(8),.md-typeset .tabbed-set>input:nth-child(7).focus-visible~.tabbed-labels>:nth-child(7),.md-typeset .tabbed-set>input:nth-child(6).focus-visible~.tabbed-labels>:nth-child(6),.md-typeset .tabbed-set>input:nth-child(5).focus-visible~.tabbed-labels>:nth-child(5),.md-typeset .tabbed-set>input:nth-child(4).focus-visible~.tabbed-labels>:nth-child(4),.md-typeset .tabbed-set>input:nth-child(3).focus-visible~.tabbed-labels>:nth-child(3),.md-typeset .tabbed-set>input:nth-child(2).focus-visible~.tabbed-labels>:nth-child(2),.md-typeset .tabbed-set>input:nth-child(1).focus-visible~.tabbed-labels>:nth-child(1) {
  background-color: var(--md-accent-fg-color--transparent);
}

.md-typeset .tabbed-set>input:nth-child(20):checked~.tabbed-content>:nth-child(20),.md-typeset .tabbed-set>input:nth-child(19):checked~.tabbed-content>:nth-child(19),.md-typeset .tabbed-set>input:nth-child(18):checked~.tabbed-content>:nth-child(18),.md-typeset .tabbed-set>input:nth-child(17):checked~.tabbed-content>:nth-child(17),.md-typeset .tabbed-set>input:nth-child(16):checked~.tabbed-content>:nth-child(16),.md-typeset .tabbed-set>input:nth-child(15):checked~.tabbed-content>:nth-child(15),.md-typeset .tabbed-set>input:nth-child(14):checked~.tabbed-content>:nth-child(14),.md-typeset .tabbed-set>input:nth-child(13):checked~.tabbed-content>:nth-child(13),.md-typeset .tabbed-set>input:nth-child(12):checked~.tabbed-content>:nth-child(12),.md-typeset .tabbed-set>input:nth-child(11):checked~.tabbed-content>:nth-child(11),.md-typeset .tabbed-set>input:nth-child(10):checked~.tabbed-content>:nth-child(10),.md-typeset .tabbed-set>input:nth-child(9):checked~.tabbed-content>:nth-child(9),.md-typeset .tabbed-set>input:nth-child(8):checked~.tabbed-content>:nth-child(8),.md-typeset .tabbed-set>input:nth-child(7):checked~.tabbed-content>:nth-child(7),.md-typeset .tabbed-set>input:nth-child(6):checked~.tabbed-content>:nth-child(6),.md-typeset .tabbed-set>input:nth-child(5):checked~.tabbed-content>:nth-child(5),.md-typeset .tabbed-set>input:nth-child(4):checked~.tabbed-content>:nth-child(4),.md-typeset .tabbed-set>input:nth-child(3):checked~.tabbed-content>:nth-child(3),.md-typeset .tabbed-set>input:nth-child(2):checked~.tabbed-content>:nth-child(2),.md-typeset .tabbed-set>input:nth-child(1):checked~.tabbed-content>:nth-child(1) {
  display: block;
}

:root {
  --md-tasklist-icon:
    url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M1 12C1 5.925 5.925 1 12 1s11 4.925 11 11-4.925 11-11 11S1 18.075 1 12Zm16.28-2.72a.751.751 0 0 0-.018-1.042.751.751 0 0 0-1.042-.018l-5.97 5.97-2.47-2.47a.751.751 0 0 0-1.042.018.751.751 0 0 0-.018 1.042l3 3a.75.75 0 0 0 1.06 0Z'/></svg>");
  --md-tasklist-icon--checked:
    url("data:image/svg+xml;charset=utf-8,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 24 24'><path d='M1 12C1 5.925 5.925 1 12 1s11 4.925 11 11-4.925 11-11 11S1 18.075 1 12Zm16.28-2.72a.751.751 0 0 0-.018-1.042.751.751 0 0 0-1.042-.018l-5.97 5.97-2.47-2.47a.751.751 0 0 0-1.042.018.751.751 0 0 0-.018 1.042l3 3a.75.75 0 0 0 1.06 0Z'/></svg>");
}

.md-typeset .task-list-item {
  position: relative;
  list-style-type: none;
}
[dir="ltr"] .md-typeset .task-list-item [type=checkbox]{
  left: -2em;
}
[dir="rtl"] .md-typeset .task-list-item [type=checkbox]{
  right: -2em;
}
.md-typeset .task-list-item [type=checkbox] {
  position: absolute;
  top: 0.45em;
}
.md-typeset .task-list-control [type=checkbox] {
  z-index: -1;
  opacity: 0;
}
[dir="ltr"] .md-typeset .task-list-indicator::before{
  left: -1.5em;
}
[dir="rtl"] .md-typeset .task-list-indicator::before{
  right: -1.5em;
}
.md-typeset .task-list-indicator::before {
  position: absolute;
  top: 0.15em;
  width: 1.25em;
  height: 1.25em;
  background-color: var(--md-default-fg-color--lightest);
  -webkit-mask-image: var(--md-tasklist-icon);
          mask-image: var(--md-tasklist-icon);
  -webkit-mask-position: center;
          mask-position: center;
  -webkit-mask-repeat: no-repeat;
          mask-repeat: no-repeat;
  -webkit-mask-size: contain;
          mask-size: contain;
  content: "";
}
.md-typeset [type=checkbox]:checked+.task-list-indicator::before {
  background-color: #00e676;
  -webkit-mask-image: var(--md-tasklist-icon--checked);
          mask-image: var(--md-tasklist-icon--checked);
}

:root>* {
  --md-mermaid-font-family: var(--md-text-font-family), sans-serif;
  --md-mermaid-edge-color: var(--md-code-fg-color);
  --md-mermaid-node-bg-color: var(--md-accent-fg-color--transparent);
  --md-mermaid-node-fg-color: var(--md-accent-fg-color);
  --md-mermaid-label-bg-color: var(--md-default-bg-color);
  --md-mermaid-label-fg-color: var(--md-code-fg-color);
}

.mermaid {
  margin: 1em 0;
  line-height: normal;
}

@media screen and (min-width: 45em) {
  [dir="ltr"] .md-typeset .inline{
    float: left;
  }
  [dir="rtl"] .md-typeset .inline{
    float: right;
  }
  [dir="ltr"] .md-typeset .inline{
    margin-right: 0.8rem;
  }
  [dir="rtl"] .md-typeset .inline{
    margin-left: 0.8rem;
  }
  .md-typeset .inline {
    width: 11.7rem;
    margin-top: 0;
    margin-bottom: 0.8rem;
  }
  [dir="ltr"] .md-typeset .inline.end{
    float: right;
  }
  [dir="rtl"] .md-typeset .inline.end{
    float: left;
  }
  [dir="ltr"] .md-typeset .inline.end{
    margin-left: 0.8rem;
    margin-right: 0;
  }
  [dir="rtl"] .md-typeset .inline.end{
    margin-right: 0.8rem;
    margin-left: 0;
  }
}